import { Host, h } from "@stencil/core";
export class CradlepointVideo {
    constructor() {
        this.toggleVideoPopup = () => {
            let host = this.host;
            let videoUrl = host.getAttribute('video-url');
            let body = host.closest('body');
            if (host.getAttribute('data-active') == 'false') {
                let backDrop = document.createElement('div');
                backDrop.setAttribute("id", "modal-backDrop");
                body.appendChild(backDrop);
                let popupWrapper = document.createElement('div');
                popupWrapper.setAttribute("class", "popup video-popup-wrapper");
                popupWrapper.setAttribute("style", `
      width: ${host.style.width};
      top: ${host.offsetTop}px;
      max-width:${host.style.maxWidth};
    `);
                popupWrapper.innerHTML = `<span class='close'><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512" width="24px" height="24px"><path d="M342.6 150.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L192 210.7 86.6 105.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L146.7 256 41.4 361.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0L192 301.3 297.4 406.6c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L237.3 256 342.6 150.6z"/></svg></span>
      <iframe src="${videoUrl}" style="aspect-ratio:${host.style.aspectRatio};" class="videoIframe" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullScreen=""></iframe>`;
                body.appendChild(popupWrapper);
                host.dataset.active = 'true';
                let close = body.querySelector('.video-popup-wrapper .close');
                close.addEventListener('click', function () {
                    body.querySelector('.video-popup-wrapper').remove();
                    host.dataset.active = 'false';
                    body.querySelector('#modal-backDrop').remove();
                });
                body.querySelector('#modal-backDrop').addEventListener('click', function () {
                    body.querySelector('.video-popup-wrapper').remove();
                    host.dataset.active = 'false';
                    body.querySelector('#modal-backDrop').remove();
                });
            }
            else {
                body.querySelector('.video-popup-wrapper').remove();
                host.dataset.active = 'false';
                body.querySelector('#modal-backDrop').remove();
            }
        };
        this.videoUrl = undefined;
        this.bgImage = undefined;
        this.width = '100%';
        this.aspectRatio = '16:9';
        this.popupWidth = '100%';
        this.maxWidth = '1280px';
    }
    render() {
        let featuredImage = '';
        if (this.videoUrl) {
            var regExp = /^.*(youtu\.be\/|v\/|u\/\w\/|embed\/|watch\?v=|\&v=)([^#\&\?]*).*/;
            var match = this.videoUrl.match(regExp);
            if (match && match[2].length == 11) {
                var id = match[2];
                featuredImage = 'https://img.youtube.com/vi/' + id + '/maxresdefault.jpg';
            }
        }
        return (h(Host, { key: 'aeb2c46a5dcf2c7de696c677706f360286e910ed', style: {
                width: this.width,
                maxWidth: this.maxWidth,
                backgroundImage: this.bgImage ? `url(${this.bgImage})` : `url(${featuredImage})`,
                aspectRatio: this.aspectRatio.replace(':', '/'),
            }, onClick: this.toggleVideoPopup, "data-active": "false" }));
    }
    static get is() { return "cradlepoint-video"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["cradlepoint-video.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["cradlepoint-video.css"]
        };
    }
    static get properties() {
        return {
            "videoUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "video-url",
                "reflect": false
            },
            "bgImage": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "bg-image",
                "reflect": false
            },
            "width": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "width",
                "reflect": false,
                "defaultValue": "'100%'"
            },
            "aspectRatio": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "aspect-ratio",
                "reflect": false,
                "defaultValue": "'16:9'"
            },
            "popupWidth": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "popup-width",
                "reflect": false,
                "defaultValue": "'100%'"
            },
            "maxWidth": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "max-width",
                "reflect": false,
                "defaultValue": "'1280px'"
            }
        };
    }
    static get elementRef() { return "host"; }
}
//# sourceMappingURL=cradlepoint-video.js.map
