import { Fragment, Host, h } from "@stencil/core";
import { formatHREF } from "../../utils/utils";
export class NavLang {
    constructor() {
        this.jsonData = {
            title: 'Discover Cradlepoint near you',
            description: "We have dedicated teams in regions the world over. We're here to answer your questions and connect you with the perfect Wireless WAN solution for your unique business needs. ",
            "background-image": 'https://img.cradlepoint.com/auto-mapping-folder/2021/02/world-map-dotted.png',
            columns: [{}],
            additional_details: '',
            excluded_slugs: '',
            slugs: ''
        };
        this.hideLanguageNav = () => {
            this.host.classList.add('hidden');
            let regionTitles = this.host.shadowRoot.querySelectorAll('.region-title');
            regionTitles === null || regionTitles === void 0 ? void 0 : regionTitles.forEach((regionTitle) => (regionTitle.dataset.open = 'false'));
            if (document.querySelector('body #modal-backDrop')) {
                document.querySelector('body #modal-backDrop').remove();
            }
        };
        this.toggleRegions = (event) => {
            let target = event.target;
            let regionTitles = this.host.shadowRoot.querySelectorAll('.region-title');
            regionTitles.forEach((regionTitle) => {
                regionTitle.dataset.open = 'false';
            });
            target.dataset.open = (target.dataset.open == 'false') ? 'true' : 'false';
        };
        this.domain = 'cradlepoint.com';
        this.json = undefined;
    }
    async componentWillLoad() {
        if (this.json) {
            return fetch(this.json)
                .then(response => response.json())
                .then(data => {
                let bgImage;
                if (data.intl_background_image) {
                    bgImage = data.intl_background_image;
                    bgImage.startsWith('/wp-content/uploads') && (bgImage = bgImage.replace('/wp-content/uploads', 'https://img.cradlepoint.com/auto-mapping-folder'));
                }
                this.jsonData = {
                    title: data.intl_title && data.intl_title,
                    description: data.intl_description && data.intl_description,
                    "background-image": bgImage && bgImage,
                    columns: data.intl_column && data.intl_column,
                    additional_details: data.intl_additional_details && data.intl_additional_details,
                    excluded_slugs: data.intl_excluded_slugs && data.intl_excluded_slugs,
                    slugs: data.intl_slugs && data.intl_slugs
                };
            })
                .catch(error => console.log(error));
        }
        return null;
    }
    handleResize() {
        clearTimeout(resizeTimeout);
        var resizeTimeout = setTimeout(() => {
            let regionTitles = this.host.shadowRoot.querySelectorAll('.region-title');
            if (window.innerWidth > 767) {
                regionTitles === null || regionTitles === void 0 ? void 0 : regionTitles.forEach((regionTitle) => (regionTitle.dataset.open = 'false'));
            }
        }, 100);
    }
    render() {
        return (this.jsonData && (h(Host, { key: 'cb20341dd8b85f9deba52a7ce9d2211293b3b588', style: {
                backgroundImage: `url(${this.jsonData['background-image']})`
            } }, h("div", { key: 'ed4748855fd4a223ef7e595c3b6061fb5360289d', class: "title-container" }, h("button", { key: 'b94fe9aebf0418fc4ff71e28683ab79fafb48823', class: "button-close", onClick: this.hideLanguageNav }, h("svg", { key: '4ed10173d9efbcd619309a3804dcc76d09b7e8cc', class: "svg-inline--fa fa-xmark", "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "xmark", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 384 512", "data-fa-i2svg": "" }, h("path", { key: '9ae8035b95d3e6a304e7717e13a38bf8aab2fcf0', fill: "currentColor", d: "M342.6 150.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L192 210.7 86.6 105.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L146.7 256 41.4 361.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0L192 301.3 297.4 406.6c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L237.3 256 342.6 150.6z" }))), h("h2", { key: '3e7d23f9a21757ebe5f60d4d96b9a83e65e9d50d', class: "title" }, this.jsonData.title), h("p", { key: 'e1fe62db2ec5af88191f4e064b223139cd9b0634', class: "description" }, this.jsonData.description)), this.jsonData.columns && (h("div", { key: 'b534974287b11fc41a8d5ceee3f302bfa6752973', class: "regions" }, this.jsonData.columns.map((region) => {
            let module = region.module;
            return (h("div", { class: "region-group" }, module.map(countries => {
                return (h("div", { class: "region" }, h("h3", { class: "region-title", "data-open": "false", onClick: this.toggleRegions }, countries.label, h("span", null, h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "16", width: "14", viewBox: "0 0 448 512" }, h("path", { fill: "currentColor", d: "M201.4 342.6c12.5 12.5 32.8 12.5 45.3 0l160-160c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L224 274.7 86.6 137.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l160 160z" })))), h("ul", { class: "countries" }, countries.languages.map((country) => {
                    return (country.country_languages && (h("li", { class: "country" }, h("span", { class: "country-name" }, country.country), h("div", { class: "languages" }, country.country_languages.map((language, index) => {
                        return h(Fragment, null, index !== 0 && h("span", null, "\u00A0\u2014\u00A0"), h("a", { href: formatHREF(this.domain, language.hreflang), class: "language", "data-page-slug": language.hreflang.replace('-', '_'), "data-id": language.link, "data-bg": "", "data-hreflang": language.hreflang }, h("span", null, language.language)));
                    })))));
                }))));
            })));
        }))), this.jsonData.additional_details && (h("div", { key: 'e3fba63e986af572b90d5be27be5286137da54d2', class: "additional-details" }, h("div", { key: '53a6f9c916431e918cee6dbbd85489b5b87e86f5', class: "additional-details-inner", innerHTML: this.jsonData.additional_details }))))));
    }
    static get is() { return "cradlepoint-nav-lang"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["nav-lang.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nav-lang.css"]
        };
    }
    static get properties() {
        return {
            "domain": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "domain",
                "reflect": false,
                "defaultValue": "'cradlepoint.com'"
            },
            "json": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "json",
                "reflect": false
            }
        };
    }
    static get elementRef() { return "host"; }
    static get listeners() {
        return [{
                "name": "resize",
                "method": "handleResize",
                "target": "window",
                "capture": false,
                "passive": true
            }];
    }
}
//# sourceMappingURL=nav-lang.js.map
