import { Fragment, Host, h } from "@stencil/core";
import { formatHREF } from "../../utils/utils";
export class NavMain {
    constructor() {
        this.loaded = false;
        this.isActive = false;
        this.jsonData = null;
        this.showIconsWrapper = false;
        this.getPhoneSVG = (className, fillColor = '#fff') => {
            return (h("svg", { class: className, xmlns: "http://www.w3.org/2000/svg", width: 29, height: 29, preserveAspectRatio: "xMidYMid meet", viewBox: "0 0 16 16", style: { transform: 'rotate(360deg)' } }, h("path", { fill: "none", stroke: fillColor, "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "1.5", d: "M1.75 1.75c0 8.5 4 12.5 12.5 12.5v-4l-3.5-1l-1 1.5c-2 0-4.5-2.5-4.5-4.5l1.5-1l-1-3.5zm8 0c2.5 0 4.5 2 4.5 4.5m-4.5-2c1 0 2 1 2 2" })));
        };
        this.getSearchSVG = (className, fillColor = '#fff') => {
            return (h("svg", { class: className, width: 29, height: 29, viewBox: "0 0 29 29", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, h("circle", { cx: "11", cy: "11", r: "9.5", stroke: fillColor, "stroke-width": "3" }), h("rect", { x: "16", y: "19.614", width: "5", height: "13", transform: "rotate(-46.2862 16 19.614)", fill: fillColor })));
        };
        this.getSignInSVG = (fillColor = 'white') => {
            return (h("svg", { style: { width: '18px' }, "data-name": "Layer 1", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 15 16" }, h("path", { style: { strokeWidth: '0px', fill: fillColor }, class: "cls-1", fill: fillColor, "fill-rule": 'evenodd', d: "M6,0v4h-1V1H1v14h4v-3h1v4H0V0h6ZM9.65,13.35l-5.35-5.36,5.35-5.35.65.71-4.14,4.15h8.84v1H6.21l4.09,4.14-.65.71Z" })));
        };
        this.getAngleRightSVG = () => {
            return (h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "16", width: "10", viewBox: "0 0 320 512" }, h("path", { d: "M278.6 233.4c12.5 12.5 12.5 32.8 0 45.3l-160 160c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3L210.7 256 73.4 118.6c-12.5-12.5-12.5-32.8 0-45.3s32.8-12.5 45.3 0l160 160z" })));
        };
        this.getLinkClass = (title, subtitle) => {
            let linkClass = `${title} ${subtitle}`;
            return linkClass.replace('-', '_').toLowerCase().split(' ').join('_');
        };
        this.toggleNav = (event) => {
            var _a, _b;
            event.preventDefault();
            let sr = this.host.shadowRoot;
            let header = sr.querySelector('header');
            this.isActive = !this.isActive;
            this.host.classList.toggle('active');
            if (document.querySelector('body #modal-backDrop')) {
                document.querySelector('body #modal-backDrop').remove();
            }
            if (this.host.classList.contains('active')) {
                let backDrop = document.createElement('div');
                backDrop.setAttribute("id", "modal-backDrop");
                document.querySelector('body').appendChild(backDrop);
            }
            if (!this.isActive) {
                setTimeout(() => {
                    header.classList.remove('level-2', 'level-3', 'level-4');
                }, 150);
            }
            (_a = document.querySelector(`${this.searchForm}`)) === null || _a === void 0 ? void 0 : _a.classList.add('hidden');
            (_b = document.querySelector(`${this.navLang}`)) === null || _b === void 0 ? void 0 : _b.classList.add('hidden');
        };
        this.switchColumn2 = (event) => {
            let sr = this.host.shadowRoot;
            let el = event.composedPath()[0];
            let col1As = sr.querySelectorAll('.column-1 li a');
            let col23Items = sr.querySelectorAll('.column-2-3__item');
            let newActiveItem = sr.querySelector(`.column-2-3__item[data-target-name="${el.dataset.target}"]`);
            let header = sr.querySelector('header');
            col1As.forEach(item => item.classList.remove('active'));
            el.classList.add('active');
            col23Items.forEach(item => item.classList.remove('active'));
            newActiveItem.classList.add('active');
            header.classList.contains('mobile') && header.classList.add('level-2');
        };
        this.switchColumn3 = (event) => {
            event.preventDefault();
            let sr = this.host.shadowRoot;
            let el = event.composedPath()[0];
            let newActiveItem = sr.querySelector(`.sub-menu[data-target-name="${el.dataset.target}"]`);
            let header = sr.querySelector('header');
            if (header.classList.contains('mobile')) {
                header.classList.remove('level-2');
                header.classList.add('level-3');
                newActiveItem.classList.add('active');
            }
        };
        this.backToLevel1 = () => {
            let sr = this.host.shadowRoot;
            let header = sr.querySelector('header');
            header.classList.contains('mobile') && header.classList.remove('level-2');
        };
        this.backToLevel2 = () => {
            let sr = this.host.shadowRoot;
            let header = sr.querySelector('header');
            let level3Items = header.querySelectorAll('.column-2 .has-sub-menu .sub-menu');
            header.classList.contains('mobile') && header.classList.remove('level-3');
            header.classList.contains('mobile') && header.classList.add('level-2');
            let level3ItemsTimeout = setTimeout(() => {
                level3Items.forEach(item => {
                    item.classList.remove('active');
                });
                clearTimeout(level3ItemsTimeout);
            }, 500);
        };
        this.toggleSearch = (event) => {
            var _a, _b;
            event.preventDefault();
            this.host.classList.remove('active');
            if (!document.querySelector(`${this.searchForm ? this.searchForm : '.search-form-div'}`).classList.contains('hidden')) {
                if (document.querySelector('body #modal-backDrop')) {
                    document.querySelector('body #modal-backDrop').remove();
                }
            }
            else {
                if (document.querySelector('body #modal-backDrop')) {
                    document.querySelector('body #modal-backDrop').remove();
                }
                let backDrop = document.createElement('div');
                backDrop.setAttribute("id", "modal-backDrop");
                document.querySelector('body').appendChild(backDrop);
            }
            (_a = document.querySelector(`${this.searchForm ? this.searchForm : '.search-form-div'}`)) === null || _a === void 0 ? void 0 : _a.classList.toggle('hidden');
            (_b = document.querySelector(`${this.navLang}`)) === null || _b === void 0 ? void 0 : _b.classList.add('hidden');
        };
        this.toggleNavLang = (event) => {
            var _a, _b;
            event.preventDefault();
            if (document.querySelector('body #modal-backDrop')) {
                document.querySelector('body #modal-backDrop').remove();
            }
            if (this.host.querySelector('cradlepoint-nav-lang').classList.contains('hidden')) {
                let backDrop = document.createElement('div');
                backDrop.setAttribute("id", "modal-backDrop");
                document.querySelector('body').appendChild(backDrop);
            }
            this.host.classList.remove('active');
            (_a = document.querySelector(`${this.navLang}`)) === null || _a === void 0 ? void 0 : _a.classList.remove('hidden');
            (_b = document.querySelector(`${this.searchForm ? this.searchForm : '.search-form-div'}`)) === null || _b === void 0 ? void 0 : _b.classList.add('hidden');
        };
        this.domain = 'cradlepoint.com';
        this.json = undefined;
        this.logo = 'https://img.cradlepoint.com/auto-mapping-folder/2022/07/cradlepoint-po-ericsson-logo-long-reverse.png';
        this.logoLight = undefined;
        this.logoDark = undefined;
        this.searchForm = undefined;
        this.navLang = undefined;
        this.showContact = false;
        this.showSearch = false;
        this.showLanguageNav = false;
        this.showSignIn = false;
        this.altMobileLayout = false;
        this.countryCode = undefined;
        this.activeLang = undefined;
        this.phoneNo = undefined;
        this.homeLink = undefined;
        this.hoverTextColor = '#1174e6';
    }
    async componentWillLoad() {
        if (this.showContact || this.showSearch || this.showLanguageNav || this.showSignIn) {
            this.showIconsWrapper = true;
        }
        if (this.json) {
            return fetch(this.json)
                .then(response => response.json())
                .then(data => {
                this.jsonData = data;
                this.loaded = true;
            })
                .catch(error => console.log(error));
        }
        return null;
    }
    componentDidLoad() {
        (window.innerWidth < 767) && this.host.shadowRoot.querySelector('header').classList.add('mobile');
    }
    handleResize() {
        clearTimeout(resizeTimeout);
        var resizeTimeout = setTimeout(() => {
            if (window.innerWidth < 768) {
                this.host.shadowRoot.querySelector('header').classList.add('mobile');
            }
            else {
                this.host.shadowRoot.querySelector('header').classList.remove('mobile');
            }
        }, 100);
    }
    render() {
        return (h(Host, { key: 'bee7480963fc100472ae8c818dc7c675518f04a8', class: this.loaded ? 'loaded' : '', style: {
                '--cwc-nav-hover-text-color': this.hoverTextColor,
            } }, this.jsonData && (h("header", { key: 'd9bee90c043f24c7a727f2b6e7aed34d0d2061c7', class: this.altMobileLayout == true ? 'alt-mobile-layout' : '' }, h("div", { key: 'af68b9c7351c42058bfd7899886c42df73e4bf90', class: "header-inner" }, h("div", { key: '6524f5b794d2b43da5695d6d5262f3d453b8555e', class: "header-inner__left" }, h("button", { key: 'a00cd294415950e3bd62a51c356b8c3a33d239fd', class: "nav-toggle", "aria-expanded": this.isActive, "aria-label": "Toggle navigation", onClick: this.toggleNav }, h("slot", { key: '593e5925dee322b2551667f5eb756ee8e8cdc73a', name: "icon-toggle-nav" })), h("a", { key: '3bf1b6d1d533a1530077819743abd519ad276667', href: this.homeLink ? this.homeLink : '/', class: "header__logo header__home-link" }, h("slot", { key: 'de2e7e33fb768a7dbe14d91be9345023facfd407', name: "header-logo" }))), this.showIconsWrapper && (h("div", { key: '3af0ba3e6cf5581b8398da2733cac2695e3e6994', class: "header-icons-wrapper" }, (this.showContact && this.phoneNo) && (h("a", { key: '9033725a12cc7f0eae7c3eb113cd403c8c8d567d', href: 'tel:' + this.phoneNo, class: 'header-icons-wrapper__icon header-icons-wrapper__phone', "data-toggle": "tooltip", title: this.phoneNo }, h("slot", { key: '11e48e32e486fb6a2e7e9973e48861ffaa2fcf36', name: "icon-phone" }))), this.showSearch && (h("a", { key: '8dc22a1a1b316b9f231a3de9fe645c6e8c0f0966', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__search', onClick: this.toggleSearch }, h("slot", { key: '6a36b85c6cda2856bcb7fcb2956fc3c1613aabb4', name: "icon-search" }))), this.showLanguageNav && (h("a", { key: 'a4940cd32e790de9f4359b546f5aab800ca05cba', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__language', onClick: this.toggleNavLang }, h("slot", { key: '58d33629b090d837698860bf36e1d92d84fa3ead', name: "icon-globe" }), h("div", { key: '5f91026d6e5a90cc410200651996a77b835aaa7d', class: 'map-details' }, h("p", { key: 'c6817e26bc1eab162ee12db01e77cf502e62a3e7' }, this.countryCode, " ", h("svg", { key: '44cfecd7b25bfab98a5f81357d5770c6ba0fe92d', class: 'svg-inline--fa fa-angle-down', "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "angle-down", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 448 512", "data-fa-i2svg": "" }, h("path", { key: 'cd5eaaa602ca6d0576ed5231342daaed9d1a5a10', fill: "currentColor", d: "M201.4 342.6c12.5 12.5 32.8 12.5 45.3 0l160-160c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L224 274.7 86.6 137.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l160 160z" }))), h("span", { key: '93ceb8fa7d56889eb86d59228593d60a035ccb78' }, this.activeLang)))), this.showSignIn && (h("a", { key: '67276e37a5169f0608b9b2122e4b13397f44c1b4', href: "/sign-in", class: 'header-icons-wrapper__icon header-icons-wrapper__sign-in' }, this.getSignInSVG('white'), h("span", { key: 'e0d668d3e96a713c508c3668e9a6f82c407d421c' }, "SIGN IN")))))), h("div", { key: '0ff6492b068a72efb4047f1b926e77920d2139fe', class: "dropdown-container" }, h("div", { key: 'edf5c2307ae946c6f1e283d0d39f6d9bd3d47817', class: "column-1-container" }, this.showIconsWrapper && (h("div", { key: '66f248cde727c5910971e2098c85461da296f0ea', class: "icons-wrapper" }, (this.showContact && this.phoneNo) && (h("a", { key: 'fca537f50e4d42e96f75aa602bcea5a829f768b5', href: 'tel:' + this.phoneNo, class: 'header-icons-wrapper__icon header-icons-wrapper__phone', "data-toggle": "tooltip", title: this.phoneNo }, h("slot", { key: 'a3473b1150bfa9892d017f2afe9398b8372a84ae', name: "icon-phone-mobile" }))), this.showSearch && (h("a", { key: 'b2f81a7e9659d6beda25ecf61f74b46b8c3ddbe6', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__search', onClick: this.toggleSearch }, h("slot", { key: 'c84a6cb0b04e4c4b27ba9c63019b0831498626b5', name: "icon-search-mobile" }))), this.showLanguageNav && (h("a", { key: 'd8fd037181069f4c4d8e6caf3d0338bafa34fa39', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__language', onClick: this.toggleNavLang }, h("slot", { key: 'f399cb40a3cf8c1d12a82af2f82411b216e81d9a', name: "icon-globe-mobile" }), h("i", { key: '309e9648d87840f3e62d9c9e1526f4a18313e7e0', class: 'languageFlags white-globe hidden' }), h("div", { key: '5d6841c01fc795c5f7894945ac6eab6eb6445952', class: 'map-details' }, h("p", { key: '96e95fa0d575d35ced9b7078acc82b8d2b39a830' }, this.countryCode, " ", h("svg", { key: '6b5b620a39e3a81470cdba61842f043083123985', class: 'svg-inline--fa fa-angle-down', "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "angle-down", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 448 512", "data-fa-i2svg": "" }, h("path", { key: '2149061e5486adc159e48b3cb71d6005e2029476', fill: "currentColor", d: "M201.4 342.6c12.5 12.5 32.8 12.5 45.3 0l160-160c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L224 274.7 86.6 137.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l160 160z" }))), h("span", { key: 'd033040acc5683261ef1e054ac26ad2a7998941c' }, this.activeLang)))), this.showSignIn && (h("a", { key: '8265fb99dc6e19babae03037f0d573538b4c662e', href: "/sign-in", class: 'header-icons-wrapper__icon header-icons-wrapper__sign-in' }, this.getSignInSVG('white'))))), h("ul", { key: '85bc0f3f7a642f2e39fad6190be975f18f12ebdc', class: "dropdown-column column-1 list-none" }, this.jsonData.main_navigation_v2.map((item, index) => {
            return (h("li", null, h("a", { href: "#", "data-target": (item.title.toLowerCase()).split(' ').join('-'), class: `nav_${(item.title.toLowerCase()).split(' ').join('_')} ${index == 0 ? 'active' : ''}`, onClick: this.switchColumn2 }, h("span", null, item.title), " ", this.getAngleRightSVG())));
        })), this.jsonData.main_navigation_v2[0]['cta'] && (h("div", { key: 'f5ccd0f8f994a6be72a7bad5957397d4854931cf', class: "column-3 type-2 green-cta green-cta__mobile-default" }, h("div", { key: '5a534c60a36f27e83cb3df941509af6b7264f2c9', class: "content-wrapper" }, this.jsonData.main_navigation_v2[0]['cta']['title'] && (h(Fragment, { key: '55857d92da982300a8127b50713778209b495de3' }, h("h3", { key: 'e9207d98254fa8ddb519457f9ed258ebe0e6769b', class: "green-cta__title" }, this.jsonData.main_navigation_v2[0]['cta']['title']))), this.jsonData.main_navigation_v2[0]['cta']['short_description'] && h("p", { key: '1cf4577a1627691732020cf1d5f0cb136e034aff', class: "green-cta__description" }, this.jsonData.main_navigation_v2[0]['cta']['short_description']), this.jsonData.main_navigation_v2[0]['cta']['button_type'] == 'v1' && this.jsonData.main_navigation_v2[0]['cta']['button'] && (h("cradlepoint-button-cta", { key: '187305bdb633da6fe184ac9ce58e3a9efc2b5bff', link: formatHREF(this.domain, this.jsonData.main_navigation_v2[0]['cta']['button']['url']) }, this.jsonData.main_navigation_v2[0]['cta']['button']['title'])), this.jsonData.main_navigation_v2[0]['cta']['button_type'] == 'v2' && this.jsonData.main_navigation_v2[0]['cta']['buttons'] && (h("ul", { key: '9f7e3afb2a3f87f73701f2d43d312e0416c6fe51' }, this.jsonData.main_navigation_v2[0]['cta']['buttons'].map((button) => {
            return (h("li", { class: "no-icon" }, h("a", { href: formatHREF(this.domain, button['button']['url']), target: "_self", class: "not-button" }, button['button']['title'])));
        }))))))), h("div", { key: '497b21608f2abfcb2238e9f84c4631e7528b4f66', class: "dropdown-column column-2-3__container" }, this.jsonData.main_navigation_v2.map((item, index) => {
            return (h("div", { class: `column-2-3__item ${index == 0 ? 'active' : ''}`, "data-target-name": (item.title.toLowerCase()).split(' ').join('-') }, h("div", { class: "mid-container" }, h("a", { href: "#", class: "sub-title", onClick: this.backToLevel1 }, this.getAngleRightSVG(), h("span", null, item.title)), item.modules.length > 0 && item.modules.map((module) => {
                if (module.acf_fc_layout == 'cta') {
                    let { hr, icon, short_description, title, link } = module;
                    return (h("div", { class: `column-2__cta` }, h("div", { class: `column-2__cta-content-wrapper${hr ? '-with-hr' : ''}` }, title && h("h3", { class: "column-2__cta-title" }, title), (icon || short_description) && (h("div", { class: "column-2__cta-content" }, icon && h("img", { src: icon, alt: "icon", width: "23", height: "23" }), short_description && (h("div", { style: {
                            color: 'var(--cwc-color-secondary-900, #242424)'
                        }, innerHTML: short_description })))), link && (h("a", { class: "column-2__cta-link", href: formatHREF(this.domain, link.url), target: link.target ? link.target : '_self' }, link.title)))));
                }
                else {
                    let ulClass = `column-2 list-none _nav_v2_${item.modules[0].acf_fc_layout}`;
                    switch (item.modules[0].acf_fc_layout) {
                        case 'link_title_description_repeater':
                            ulClass += ' type-2';
                            break;
                        default:
                            ulClass += ' type-1';
                            break;
                    }
                    switch (item.modules[0].columns) {
                        case "1/3-2/3":
                            ulClass += ' one-third--two-thirds';
                            break;
                        case "2":
                            ulClass += ' two-columns';
                            break;
                    }
                    return (h("ul", { class: `${ulClass}` }, (module.acf_fc_layout == 'icon_title_repeater') && module.data.map((subItem) => {
                        return (h("li", null, subItem.show_link && h(Fragment, null, h("a", { href: formatHREF(this.domain, subItem.link.url), class: this.getLinkClass(item.title, subItem.link.title) }, subItem.icon && h("img", { src: subItem.icon, alt: `${subItem.link.title} icon`, width: "23", height: "23" }), h("span", null, subItem.link.title))), !subItem.show_link && h(Fragment, null, h("h3", null, subItem.link.title))));
                    }), (module.acf_fc_layout == 'link_title_description_repeater') && module.data.map((subItem) => {
                        let liClass, titleHTML;
                        let dataTarget = subItem.title.toLowerCase().split(' ').join('_');
                        liClass = '';
                        if (subItem.border_right == true) {
                            liClass += ' has-border-right';
                        }
                        if (subItem.icon_link_repeater.length) {
                            liClass += ' has-sub-menu';
                        }
                        if (subItem.link_title) {
                            titleHTML = (h("a", { href: formatHREF(this.domain, subItem.link.url), target: "_self", class: this.getLinkClass(item.title, subItem.link.title) }, h("h3", null, subItem.link.title)));
                        }
                        else {
                            titleHTML = h("h3", { "data-target": dataTarget, onClick: this.switchColumn3 }, subItem.title);
                        }
                        return (h("li", { class: liClass }, titleHTML, subItem.short_description && h(Fragment, null, h("div", { innerHTML: subItem.short_description })), subItem.icon_link_repeater.length && h(Fragment, null, h("ul", { class: "list-none sub-menu", "data-target-name": dataTarget }, h("a", { href: "#", class: "sub-title", onClick: this.backToLevel2 }, this.getAngleRightSVG(), h("span", null, subItem.title)), subItem.icon_link_repeater.map((iconLinkRepeaterItem) => {
                            return (h("li", null, h("a", { href: formatHREF(this.domain, iconLinkRepeaterItem.link.url), target: "_self", class: this.getLinkClass(item.title, iconLinkRepeaterItem.link.title) }, iconLinkRepeaterItem.icon && h("img", { src: iconLinkRepeaterItem.icon, alt: "Fixed sites icon", width: "23", height: "23" }), h("span", null, iconLinkRepeaterItem.link.title))));
                        })))));
                    })));
                }
            })), item['cta'] && (h("div", { class: "type-2 green-cta" }, item['cta']['icon'] && (h("div", { class: "img-wrapper" }, h("img", { src: item['cta']['icon'], alt: "icon", width: "82", height: "82" }))), h("div", { class: "content-wrapper" }, item['cta']['title'] && (h(Fragment, null, h("h3", null, item['cta']['title']), h("hr", null))), item['cta']['short_description'] && h("p", null, item['cta']['short_description']), item['cta']['button_type'] == 'v1' && item['cta']['button'] && (h("cradlepoint-button-cta", { link: formatHREF(this.domain, item['cta']['button']['url']) }, item['cta']['button']['title'])), item['cta']['button_type'] == 'v2' && item['cta']['buttons'] && (h("ul", null, item['cta']['buttons'].map((button) => {
                return (h("li", { class: "no-icon" }, h("a", { href: formatHREF(this.domain, button['button']['url']), target: "_self", class: "not-button" }, button['button']['title'])));
            }))))))));
        }))), h("div", { key: '7ba0af836ad11765e68c4de7e9f04746c94c88c4', class: "search-form-container" }, h("slot", { key: '1b010d2cab7968bdb666a525fad13fb8871a3d96', name: "search-form" })), h("div", { key: 'a4865b3eda45e13d1c8798e688ab08fcafdf504e', class: "nav-lang-container" }, h("slot", { key: '2a66c4dd50322cc86ff47e7af33d56c3cc96a1c3', name: "nav-lang" }))))));
    }
    static get is() { return "cradlepoint-nav-main"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["nav-main.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["nav-main.css"]
        };
    }
    static get properties() {
        return {
            "domain": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "domain",
                "reflect": false,
                "defaultValue": "'cradlepoint.com'"
            },
            "json": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "json",
                "reflect": false
            },
            "logo": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "logo",
                "reflect": false,
                "defaultValue": "'https://img.cradlepoint.com/auto-mapping-folder/2022/07/cradlepoint-po-ericsson-logo-long-reverse.png'"
            },
            "logoLight": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "logo-light",
                "reflect": false
            },
            "logoDark": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "logo-dark",
                "reflect": false
            },
            "searchForm": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "search-form",
                "reflect": false
            },
            "navLang": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "nav-lang",
                "reflect": false
            },
            "showContact": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "show-contact",
                "reflect": false,
                "defaultValue": "false"
            },
            "showSearch": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "show-search",
                "reflect": false,
                "defaultValue": "false"
            },
            "showLanguageNav": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "show-language-nav",
                "reflect": false,
                "defaultValue": "false"
            },
            "showSignIn": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "show-sign-in",
                "reflect": false,
                "defaultValue": "false"
            },
            "altMobileLayout": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "alt-mobile-layout",
                "reflect": false,
                "defaultValue": "false"
            },
            "countryCode": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "country-code",
                "reflect": false
            },
            "activeLang": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "active-lang",
                "reflect": false
            },
            "phoneNo": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "phone-no",
                "reflect": false
            },
            "homeLink": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "home-link",
                "reflect": false
            },
            "hoverTextColor": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "hover-text-color",
                "reflect": false,
                "defaultValue": "'#1174e6'"
            }
        };
    }
    static get elementRef() { return "host"; }
    static get listeners() {
        return [{
                "name": "resize",
                "method": "handleResize",
                "target": "window",
                "capture": false,
                "passive": true
            }];
    }
}
//# sourceMappingURL=nav-main.js.map
