import { proxyCustomElement, HTMLElement, h, Host, Fragment } from '@stencil/core/internal/client';

const carouselContainerCss = ":host{position:relative;display:block;width:100%;margin-right:auto;margin-left:auto}.content-wrapper{display:flex;width:calc(100% - 80px);height:100%;margin:0 auto;overflow:hidden}.content-wrapper.no-arrows,.content-wrapper.inside-arrows{width:100%}.content-wrapper>slot{display:flex;width:100%;height:100%;transition:transform 300ms ease-in-out;transform:translateX(-100%)}::slotted(*){display:grid;place-items:center;flex-grow:1;flex-shrink:0;width:100%;height:auto}.carousel-prev,.carousel-next{position:absolute;top:calc(50% - 20px);width:30px;height:41px;cursor:pointer;user-select:none;opacity:0.5}.carousel-prev:hover,.carousel-next:hover{opacity:0.75;transition:opacity 100ms ease-in}.carousel-prev>*,.carousel-next>*{display:block;pointer-events:none}.carousel-prev>img{margin-right:0;margin-left:auto}.carousel-next>img{margin-right:auto;margin-left:0}.carousel-prev{left:0}.carousel-next{right:0}.pagination{position:absolute;left:50%;transform:translateX(-50%);display:flex;justify-content:center;margin:10px auto 0;padding:0;user-select:none}.pagination.inside-dots{margin-top:-22px}.pagination li{display:inline-block;width:12px;height:12px;border-radius:100%;background-color:var(--cwc-color-secondary-600, #7B858B);cursor:pointer;margin:0 3px;opacity:0.5;transition:opacity 100ms ease-in}.pagination li:hover{opacity:0.75}.pagination li.active{opacity:1.0}";
const CradlepointCarouselContainerStyle0 = carouselContainerCss;

const CarouselContainer = /*@__PURE__*/ proxyCustomElement(class CarouselContainer extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.prev = () => {
            this.currentPage--;
            this.gotoPage();
            this.updatePaginations();
        };
        this.next = () => {
            this.currentPage++;
            this.gotoPage();
            this.updatePaginations();
        };
        this.slidesContainerTransitionEnd = () => {
            let multiplier = this.numChildren * 100;
            if (this.currentPage == 0 || this.currentPage > this.numChildren) {
                this.slidesContainer.style.transition = '0ms';
                if (this.currentPage > this.numChildren) {
                    this.slidesContainer.style.transform = `translateX(-100%)`;
                    this.currentPage = 1;
                }
                else if (this.currentPage == 0) {
                    this.slidesContainer.style.transform = `translateX(-${multiplier}%)`;
                    this.currentPage = this.numChildren;
                }
                let timeout = setTimeout(() => {
                    this.slidesContainer.style.transition = `transform 300ms ease-in-out`;
                    clearTimeout(timeout);
                }, 300);
            }
        };
        this.gotoPage = () => {
            this.slidesContainer.style.transform = `translateX(calc(${(this.currentPage) * (-100)}%))`;
        };
        this.updatePaginations = () => {
            const paginations = Array.from(this.host.shadowRoot.querySelectorAll('.pagination > li'));
            [...paginations].forEach(pagination => pagination.classList.remove('active'));
            if (this.currentPage > this.numChildren) {
                paginations[0].classList.add('active');
            }
            else if (this.currentPage < 1) {
                paginations[this.numChildren - 1].classList.add('active');
            }
            else {
                paginations[this.currentPage - 1].classList.add('active');
            }
        };
        this.checkIfReady = async () => {
            return new Promise(resolve => {
                let checkIfReadyInterval = setInterval(() => {
                    if (this.ready) {
                        clearInterval(checkIfReadyInterval);
                        resolve();
                    }
                }, 100);
            });
        };
        this.startAutoPlay = () => {
            this.autoplayInterval = setInterval(() => {
                this.next();
            }, this.interval);
        };
        this.handleSlotChange = () => {
            this.slidesContainer = this.host.shadowRoot.querySelector('slot');
            this.slidesContainer.addEventListener('transitionend', this.slidesContainerTransitionEnd, false);
            if (!this.ready) {
                this.numChildren = Array.from(this.host.children).length;
                let paginationsTemp = [];
                if (this.numChildren >= 1) {
                    for (let index = 0; index < this.numChildren; index++) {
                        if (index == 0) {
                            paginationsTemp.push(h("li", { class: "active", "data-page-number": "1" }));
                        }
                        else {
                            paginationsTemp.push(h("li", { "data-page-number": `${index + 1}` }));
                        }
                        if (index == (paginationsTemp.length - 1)) {
                            this.paginations = paginationsTemp;
                        }
                    }
                }
                let firstSlideClone = this.host.firstElementChild.cloneNode(true);
                let lastSlideClone = this.host.lastElementChild.cloneNode(true);
                this.host.append(firstSlideClone);
                this.host.prepend(lastSlideClone);
                this.ready = true;
                if (this.autoplay) {
                    this.checkIfReady()
                        .then(() => {
                        this.startAutoPlay();
                    });
                }
            }
        };
        this.height = 'auto';
        this.maxWidth = 'initial';
        this.showArrows = true;
        this.showDots = true;
        this.insideArrows = false;
        this.insideDots = false;
        this.autoplay = false;
        this.interval = 3000;
        this.slidesContainer = null;
        this.numChildren = 0;
        this.currentPage = 1;
        this.paginations = undefined;
        this.ready = false;
        this.autoplayInterval = undefined;
    }
    handleClick(e) {
        let el = e.composedPath()[0];
        if (el.parentNode.classList && el.parentNode.classList.contains('pagination')) {
            this.currentPage = parseInt(e.composedPath()[0].dataset.pageNumber);
            this.gotoPage();
            [...el.parentNode.children].forEach(child => child.classList.remove('active'));
            el.classList.add('active');
        }
        if (el.classList.contains('carousel-prev') || el.classList.contains('carousel-next')) {
            this.updatePaginations();
        }
    }
    handleMouseOver() {
        clearInterval(this.autoplayInterval);
    }
    handleMouseOut() {
        if (this.autoplay) {
            this.startAutoPlay();
        }
    }
    render() {
        return (h(Host, { key: '4ad6629ac49251f59350c838cf1bb75b214abf22', style: {
                maxWidth: `${this.maxWidth}`
            } }, h("div", { key: '9b911199deab8ad9db56849b22819c281e873cca', class: `content-wrapper ${!this.showArrows && 'no-arrows'} ${!this.showDots && 'no-dots'} ${this.insideArrows && 'inside-arrows'}`, style: {
                height: `${this.height}`,
            } }, h("slot", { key: '76b4cc1bc63b13a31a042511271dcacdeeb72493', onSlotchange: this.handleSlotChange })), this.showArrows && (this.numChildren > 1) && h(Fragment, { key: '3d312c200563ae0f81232e1a6776e9b7c891ab27' }, h("div", { key: '6c2a1a296d50274d32034d91f36fa5a387495906', class: "arrow arrow-left carousel-prev", onClick: this.prev }, h("img", { key: 'eed1f2685f3e092685b024af0da033f5b33004f1', src: "https://img.cradlepoint.com/auto-mapping-folder/2020/06/left-arrow.webp" })), h("div", { key: '74be3eb5118b3b038406304931e05928cfe08484', class: "arrow arrow-right carousel-next", onClick: this.next }, h("img", { key: 'c57c4a9f3fece8354f9b63474e478b94791bc210', src: "https://img.cradlepoint.com/auto-mapping-folder/2020/06/right-arrow.webp" }))), this.showDots && (this.numChildren > 1) && this.paginations &&
            h("ul", { key: 'b095aa7db0bd7b8c49431f13eb588126ea6634cd', class: `pagination ${this.insideDots && 'inside-dots'}` }, this.paginations)));
    }
    get host() { return this; }
    static get style() { return CradlepointCarouselContainerStyle0; }
}, [1, "cradlepoint-carousel-container", {
        "height": [1],
        "maxWidth": [1, "max-width"],
        "showArrows": [4, "show-arrows"],
        "showDots": [4, "show-dots"],
        "insideArrows": [4, "inside-arrows"],
        "insideDots": [4, "inside-dots"],
        "autoplay": [4],
        "interval": [2],
        "slidesContainer": [32],
        "numChildren": [32],
        "currentPage": [32],
        "paginations": [32],
        "ready": [32],
        "autoplayInterval": [32]
    }, [[0, "click", "handleClick"], [1, "mouseover", "handleMouseOver"], [1, "mouseout", "handleMouseOut"]]]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cradlepoint-carousel-container"];
    components.forEach(tagName => { switch (tagName) {
        case "cradlepoint-carousel-container":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, CarouselContainer);
            }
            break;
    } });
}

const CradlepointCarouselContainer = CarouselContainer;
const defineCustomElement = defineCustomElement$1;

export { CradlepointCarouselContainer, defineCustomElement };

//# sourceMappingURL=cradlepoint-carousel-container.js.map