import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';

const hotspotItemCss = "*{box-sizing:border-box}:host{display:none}@media (min-width: 1025px){:host{position:absolute;display:block;cursor:pointer}}.overlay{display:flex;flex-direction:column;width:100%;height:100%;opacity:0;overflow:hidden;position:relative;pointer-events:none}:host([data-active='true']) .overlay{position:absolute;z-index:100;opacity:1;overflow:visible;pointer-events:initial}.overlay>*:not(.close-button){position:absolute}.popup{display:flex;flex-direction:column;width:100%;height:100%}.close-button{position:absolute;right:0;z-index:2;display:grid;place-items:center;width:24px;height:24px;margin-right:0;margin-left:auto;border:1px solid rgba(255,255,255,0.5);border-top-right-radius:6px;outline:0;color:var(--cwc-color-white, #fff);background-color:var(--cwc-color-red, #ff3232);cursor:pointer}.close-button svg path{fill:var(--cwc-color-white, #fff)}.top-left{top:0;left:0}.top-right{top:0;right:0}.bottom-left{bottom:0;left:0}.bottom-right{bottom:0;right:0}";
const CradlepointHotspotItemStyle0 = hotspotItemCss;

const HotspotItem = /*@__PURE__*/ proxyCustomElement(class HotspotItem extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.iconSVG = h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 384 512" }, h("path", { d: "M342.6 150.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L192 210.7 86.6 105.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L146.7 256 41.4 361.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0L192 301.3 297.4 406.6c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L237.3 256 342.6 150.6z" }));
        this.toggleOverlay = () => {
            let host = this.host;
            let parent = host.parentNode;
            let allHotspots = parent.querySelectorAll('cradlepoint-hotspot-item');
            let card = host.querySelector('cradlepoint-card-simple-text');
            let popup = host.shadowRoot.querySelector('.popup');
            if (host.dataset.active == 'false') {
                allHotspots.forEach((hotspot) => {
                    hotspot.dataset.active = 'false';
                });
                host.dataset.active = 'true';
                popup.style.width = `${card.clientWidth}px`;
                popup.style.height = `${card.clientHeight}px`;
            }
            else {
                host.dataset.active = 'false';
            }
        };
        this.x = 0;
        this.y = 0;
        this.width = 0;
        this.height = 0;
        this.popupWidth = 400;
        this.popupAnchor = 'top-left';
    }
    render() {
        return (h(Host, { key: '0df642f584f9a1d73c2f7c106ecc90be543d5e62', style: {
                left: `${this.x}cqw`,
                top: `${this.y}cqw`,
                width: `${this.width}cqw`,
                height: `${this.height}cqw`,
            }, onMouseEnter: this.toggleOverlay, onMouseLeave: this.toggleOverlay, "data-active": "false" }, h("div", { key: '479e95465ea1c91054df1ce190d333d2203645a3', class: "overlay" }, h("div", { key: '26dd2ab662fc5c4e940928a76642bb14b590c8eb', class: `popup ${this.popupAnchor}`, style: { minWidth: `${this.popupWidth}px` } }, h("slot", { key: '4f6ef21a1ad6ce4765b897097a80d67681dfecf2' })))));
    }
    get host() { return this; }
    static get style() { return CradlepointHotspotItemStyle0; }
}, [1, "cradlepoint-hotspot-item", {
        "x": [2],
        "y": [2],
        "width": [2],
        "height": [2],
        "popupWidth": [2, "popup-width"],
        "popupAnchor": [1, "popup-anchor"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cradlepoint-hotspot-item"];
    components.forEach(tagName => { switch (tagName) {
        case "cradlepoint-hotspot-item":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, HotspotItem);
            }
            break;
    } });
}

const CradlepointHotspotItem = HotspotItem;
const defineCustomElement = defineCustomElement$1;

export { CradlepointHotspotItem, defineCustomElement };

//# sourceMappingURL=cradlepoint-hotspot-item.js.map