import { proxyCustomElement, HTMLElement, h, Host, Fragment } from '@stencil/core/internal/client';
import { f as formatHREF } from './utils.js';

const navLangCss = "*{box-sizing:border-box}:host{position:absolute;top:0;display:flex;flex-direction:column;align-items:center;width:100vw;height:100vh;overflow-y:scroll;padding-top:60px;color:var(--cwc-color-white, #fff);background-repeat:no-repeat;background-position:100% 0;background-color:var(--cwc-color-secondary, #333F48)}:host(.hidden){display:none}.title-container{position:relative;margin-bottom:50px;padding:0 24px;text-align:center}.button-close{display:grid;place-items:center;width:54px;height:54px;margin-left:auto;margin-right:auto;background-color:transparent;border-radius:100%;border:3px solid rgba(173,178,181,0.3);cursor:pointer}.button-close svg{width:18px;height:18px}.button-close svg path{fill:var(--cwc-color-white, #fff)}.title{margin-top:40px;font-family:var(--cwc-font-sans-serif-bold, 'Eina01-Bold');font-size:24px;font-weight:400}.description{color:var(--cwc-color-secondary-400, #A3AAAD)}.regions{width:100%;max-width:1140px;padding:0 24px;text-align:center}.region{margin-bottom:30px}.region-title{margin:0;font-family:var(--cwc-font-sans-serif-bold, 'Eina01-Bold');font-weight:400;font-size:24px;line-height:32px;color:var(--language-region-color);cursor:pointer}.region-title span{display:inline-block;width:16px;height:32px;margin-left:8px;pointer-events:none}.region-title[data-open=\"true\"] span{transform:rotate(180deg)}.region-title svg{pointer-events:none}.countries{height:0;overflow-y:hidden;list-style-type:none;margin-top:8px;padding:0}.region-title[data-open=\"true\"]+.countries{height:unset}.country{display:flex;flex-direction:column;margin-top:0}.country:not(:first-child){margin-top:15px}.country-name{color:var(--cwc-color-secondary-050, #F2F2F2);font-family:var(--cwc-font-sans-serif-bold, 'Eina01-Bold');font-weight:400;font-size:16px;margin-bottom:0;line-height:1.2}.languages{display:flex;justify-content:center;color:var(--cwc-color-secondary-400, #A3AAAD) !important;font-family:var(--cwc-font-sans-serif-regular, 'Eina01-Regular');font-size:16px;line-height:1.2}.language{margin-top:4px}.language,.language:visited{color:var(--cwc-color-secondary-400, #A3AAAD) !important;text-decoration:none}.language:hover{text-decoration:underline}.additional-details{width:100%;margin-top:30px;border:2px solid var(--cwc-color-secondary-800, #5A6973);border-left:0;border-right:0;font-size:14px;text-align:left;color:var(--cwc-color-secondary-600, #7B858B)}.additional-details-inner{max-width:1140px;margin-left:auto;margin-right:auto;padding:10px 24px}.additional-details a,.additional-details a:visited{color:var(--cwc-color-secondary-400, #A3AAAD)}@media (min-width: 768px){:host{height:fit-content}.title-container{text-align:left;padding:0 148px 0 48px}.button-close{position:absolute;top:0;right:48px}.title-container{width:100%;max-width:1140px;margin-left:auto;margin-right:auto}.title{margin:0;font-size:36px}.description{font-size:20px;line-height:1.5}.regions{display:grid;grid-template-columns:repeat(5, 1fr);gap:2rem;padding:0 48px;text-align:left}.region-group:last-child{grid-column:span 3;max-width:600px}.region-title span{display:none}.countries{height:unset;overflow-y:unset}.region-group:last-child .countries{display:grid;grid-template-columns:repeat(3, 1fr)}.languages{justify-content:left}.country{margin-top:15px}.additional-details-inner{padding-left:48px;padding-right:48px}}@media (min-width: 1025px){.title-container{padding-left:64px;padding-right:164px}.button-close{right:64px}.regions,.additional-details-inner{padding-left:64px;padding-right:64px}}";
const CradlepointNavLangStyle0 = navLangCss;

const NavLang = /*@__PURE__*/ proxyCustomElement(class NavLang extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.jsonData = {
            title: 'Discover Cradlepoint near you',
            description: "We have dedicated teams in regions the world over. We're here to answer your questions and connect you with the perfect Wireless WAN solution for your unique business needs. ",
            "background-image": 'https://img.cradlepoint.com/auto-mapping-folder/2021/02/world-map-dotted.png',
            columns: [{}],
            additional_details: '',
            excluded_slugs: '',
            slugs: ''
        };
        this.hideLanguageNav = () => {
            this.host.classList.add('hidden');
            let regionTitles = this.host.shadowRoot.querySelectorAll('.region-title');
            regionTitles === null || regionTitles === void 0 ? void 0 : regionTitles.forEach((regionTitle) => (regionTitle.dataset.open = 'false'));
            if (document.querySelector('body #modal-backDrop')) {
                document.querySelector('body #modal-backDrop').remove();
            }
        };
        this.toggleRegions = (event) => {
            let target = event.target;
            let regionTitles = this.host.shadowRoot.querySelectorAll('.region-title');
            regionTitles.forEach((regionTitle) => {
                regionTitle.dataset.open = 'false';
            });
            target.dataset.open = (target.dataset.open == 'false') ? 'true' : 'false';
        };
        this.domain = 'cradlepoint.com';
        this.json = undefined;
    }
    async componentWillLoad() {
        if (this.json) {
            return fetch(this.json)
                .then(response => response.json())
                .then(data => {
                let bgImage;
                if (data.intl_background_image) {
                    bgImage = data.intl_background_image;
                    bgImage.startsWith('/wp-content/uploads') && (bgImage = bgImage.replace('/wp-content/uploads', 'https://img.cradlepoint.com/auto-mapping-folder'));
                }
                this.jsonData = {
                    title: data.intl_title && data.intl_title,
                    description: data.intl_description && data.intl_description,
                    "background-image": bgImage && bgImage,
                    columns: data.intl_column && data.intl_column,
                    additional_details: data.intl_additional_details && data.intl_additional_details,
                    excluded_slugs: data.intl_excluded_slugs && data.intl_excluded_slugs,
                    slugs: data.intl_slugs && data.intl_slugs
                };
            })
                .catch(error => console.log(error));
        }
        return null;
    }
    handleResize() {
        clearTimeout(resizeTimeout);
        var resizeTimeout = setTimeout(() => {
            let regionTitles = this.host.shadowRoot.querySelectorAll('.region-title');
            if (window.innerWidth > 767) {
                regionTitles === null || regionTitles === void 0 ? void 0 : regionTitles.forEach((regionTitle) => (regionTitle.dataset.open = 'false'));
            }
        }, 100);
    }
    render() {
        return (this.jsonData && (h(Host, { key: 'cb20341dd8b85f9deba52a7ce9d2211293b3b588', style: {
                backgroundImage: `url(${this.jsonData['background-image']})`
            } }, h("div", { key: 'ed4748855fd4a223ef7e595c3b6061fb5360289d', class: "title-container" }, h("button", { key: 'b94fe9aebf0418fc4ff71e28683ab79fafb48823', class: "button-close", onClick: this.hideLanguageNav }, h("svg", { key: '4ed10173d9efbcd619309a3804dcc76d09b7e8cc', class: "svg-inline--fa fa-xmark", "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "xmark", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 384 512", "data-fa-i2svg": "" }, h("path", { key: '9ae8035b95d3e6a304e7717e13a38bf8aab2fcf0', fill: "currentColor", d: "M342.6 150.6c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L192 210.7 86.6 105.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3L146.7 256 41.4 361.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0L192 301.3 297.4 406.6c12.5 12.5 32.8 12.5 45.3 0s12.5-32.8 0-45.3L237.3 256 342.6 150.6z" }))), h("h2", { key: '3e7d23f9a21757ebe5f60d4d96b9a83e65e9d50d', class: "title" }, this.jsonData.title), h("p", { key: 'e1fe62db2ec5af88191f4e064b223139cd9b0634', class: "description" }, this.jsonData.description)), this.jsonData.columns && (h("div", { key: 'b534974287b11fc41a8d5ceee3f302bfa6752973', class: "regions" }, this.jsonData.columns.map((region) => {
            let module = region.module;
            return (h("div", { class: "region-group" }, module.map(countries => {
                return (h("div", { class: "region" }, h("h3", { class: "region-title", "data-open": "false", onClick: this.toggleRegions }, countries.label, h("span", null, h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "16", width: "14", viewBox: "0 0 448 512" }, h("path", { fill: "currentColor", d: "M201.4 342.6c12.5 12.5 32.8 12.5 45.3 0l160-160c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L224 274.7 86.6 137.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l160 160z" })))), h("ul", { class: "countries" }, countries.languages.map((country) => {
                    return (country.country_languages && (h("li", { class: "country" }, h("span", { class: "country-name" }, country.country), h("div", { class: "languages" }, country.country_languages.map((language, index) => {
                        return h(Fragment, null, index !== 0 && h("span", null, "\u00A0\u2014\u00A0"), h("a", { href: formatHREF(this.domain, language.hreflang), class: "language", "data-page-slug": language.hreflang.replace('-', '_'), "data-id": language.link, "data-bg": "", "data-hreflang": language.hreflang }, h("span", null, language.language)));
                    })))));
                }))));
            })));
        }))), this.jsonData.additional_details && (h("div", { key: 'e3fba63e986af572b90d5be27be5286137da54d2', class: "additional-details" }, h("div", { key: '53a6f9c916431e918cee6dbbd85489b5b87e86f5', class: "additional-details-inner", innerHTML: this.jsonData.additional_details }))))));
    }
    get host() { return this; }
    static get style() { return CradlepointNavLangStyle0; }
}, [1, "cradlepoint-nav-lang", {
        "domain": [1],
        "json": [1]
    }, [[9, "resize", "handleResize"]]]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cradlepoint-nav-lang"];
    components.forEach(tagName => { switch (tagName) {
        case "cradlepoint-nav-lang":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, NavLang);
            }
            break;
    } });
}

const CradlepointNavLang = NavLang;
const defineCustomElement = defineCustomElement$1;

export { CradlepointNavLang, defineCustomElement };

//# sourceMappingURL=cradlepoint-nav-lang.js.map