import { proxyCustomElement, HTMLElement, h, Host, Fragment } from '@stencil/core/internal/client';
import { f as formatHREF } from './utils.js';
import { d as defineCustomElement$2 } from './button-cta.js';

const navMainCss = ":host {\n  display:none;\n  position: absolute;\n  z-index: 1003;\n}\n\n* {\n  box-sizing: border-box;\n}\n\n:host(.loaded) {\n  width: 100%;\n  display: flex;\n  align-items: center;\n  background-color: var(--cwc-color-secondary, #333F48);\n  padding-right: 0rem;\n  padding-left: 0rem;\n  font-size: 1rem;\n  font-family: var(--cwc-font-sans-serif-regular, 'Eina01-Regular');\n  transition: all var(--cwc-transition-speed, 50ms) ease-in-out;\n}\n\na,\na:visited,\na:active {\n  color: inherit !important;\n}\n\n/* a:hover {\n  color: var(--cwc-color-accent-a, #009A44) !important;\n} */\n\n.list-none {\n  list-style-type: none;\n}\n\nheader {\n  width: 100%;\n  height: 60px;\n  background-color: var(--cwc-color-secondary, #333F48);\n}\n\n.header-inner {\n  display: flex;\n  align-items: center;\n  height: 60px;\n  padding: 5px 2rem;\n}\n\n.header-inner__left {\n  display: flex;\n  gap: 1rem;\n}\n\n.header__logo {\n  display: grid;\n  place-items: center;\n  text-decoration: none;\n}\n\n.header__logo img {\n  max-width: 100%;\n}\n\n.header-icons-wrapper {\n  display: none;\n  margin-left: auto;\n}\n\n.nav-toggle {\n  display: flex;\n  flex-direction: column;\n  flex-shrink: 0;\n  justify-content: center;\n  align-items: center;\n  width: 32px;\n  height: 32px;\n  border: 0;\n  background-color: rgba(255,173,0,0);\n  transition: all var(--cwc-transition-speed, 50ms);\n  cursor: pointer;\n  border: 1px solid var(--cwc-color-secondary-700, #fff);\n  border-radius: 4px;\n  color: var(--cwc-color-white);\n}\n\n:host(.active) .nav-toggle {\n  color: var(--cwc-color-secondary);\n  background-color: var(--cwc-color-white, #FFAD00);\n}\n\n.nav-toggle div {\n  position: relative;\n  width: 30px;\n  height: 30px;\n  pointer-events: none;\n}\n\n.nav-toggle span {\n  display: block;\n  position: absolute;\n  height: 4px;\n  width: 30px;\n  background-color: var(--cwc-color-white, #fff);\n  border-radius: 2px;\n  opacity: 1;\n  left: 0;\n  pointer-events: none;\n  transition: all var(--cwc-transition-speed, 50ms);\n}\n\n.nav-toggle span:first-child {\n  top: 2px;\n}\n\n:host(.active) .nav-toggle span:first-child {\n  rotate: 135deg;\n  top: 15px;\n  background-color: var(--cwc-nav-toggle-active-icon-color, #333F48);\n}\n\n.nav-toggle span:nth-child(2) {\n  top: 13px;\n}\n\n:host(.active) .nav-toggle span:nth-child(2) {\n  rotate: 359deg;\n  opacity: 0;\n}\n\n.nav-toggle span:last-child {\n  top: 24px;\n}\n\n:host(.active) .nav-toggle span:last-child {\n  rotate: -135deg;\n  top: 15px;\n  background-color: var(--cwc-nav-toggle-active-icon-color, #333F48);\n}\n\n.dropdown-container {\n  position: absolute;\n  top: 60px;\n  width: 100vw;\n  display: flex;\n  transition: all 150ms;\n  transform: translateX(-100vw);\n  overflow-x: hidden;\n}\n\n.dropdown-container .icons-wrapper a {\n  text-decoration: none;\n}\n\n:host(.active) .dropdown-container {\n  display: flex;\n  flex-wrap: no-wrap;\n  transform: translateX(0);\n}\n\n.icons-wrapper {\n  display: flex;\n  align-items: center;\n  height: 60px;\n  padding-left: 45px;\n  padding-right: 45px;\n  background-color: var(--cwc-color-primary, #FFAD00);\n}\n\n.icons-wrapper__icon:not(:first-child) {\n  margin-left: 48px;\n}\n\n.icons-wrapper__icon.icons-wrapper__sign-in {\n  margin-left: auto;\n}\n\n.column-1 {\n  flex-shrink: 0;\n  width: 100vw;\n  margin: 0;\n  padding: 0;\n  color: var(--cwc-color-secondary-900, #242424);\n  background-color: var(--cwc-color-white, #fff);\n}\n\n.column-1 li {\n  border-bottom: 1px solid #858c91;\n}\n\n.column-1 li a {\n  display: flex;\n  flex-direction: row;\n  justify-content: space-between;\n  align-items: center;\n  height: 62px;\n  padding: 0 45px;\n  color: var(--cwc-color-secondary-900, #242424);\n  font-family: var(--cwc-font-sans-serif-regular, 'Eina01-Regular');\n  text-transform: uppercase;\n  text-decoration: none;\n}\n\n.column-1 li a:hover {\n  font-family: var(--cwc-font-sans-serif-bold, 'Eina01-Bold');\n  font-weight: 400;\n}\n\n.column-1 li a span,\n.column-1 li a svg {\n  pointer-events: none;\n}\n\n.mid-container {\n  background-color: rgb(230, 232, 232);\n}\n\n.mid-container .sub-title {\n  display: flex;\n  align-items: center;\n  padding: 22.5px 45px 20px;\n  font-family: var(--cwc-font-sans-serif-bold, 'Eina01-Bold');\n  font-weight: 400;\n  text-transform: uppercase;\n  color: var(--cwc-color-secondary-900, #242424) !important;\n  background-color: var(--cwc-color-white, #fff);\n  text-decoration: none;\n}\n\n.mid-container .sub-title svg {\n  rotate: 180deg;\n  margin-top: 2px;\n  margin-right: 1rem;\n}\n\n.column-2-3__item:not(.active) {\n  display: none;\n}\n\n.column-2-3__item {\n  display: flex;\n  flex-direction: column;\n}\n\n.column-2 {\n  margin: 0;\n  padding: 16px 0;\n  font-size: 18px;\n}\n\n.column-2 h3 {\n  margin: 0;\n  padding: 16px 45px;\n  font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n  font-weight: 400;\n  font-size: 18px;\n  line-height: 16.875px;\n  color: var(--cwc-color-secondary-900, #242424) !important;\n}\n\n.column-2.type-2 ul {\n  padding-left: 0;\n}\n\n.column-2 li a {\n  display: flex;\n  align-items: center;\n  padding: 16px 45px;\n  color: var(--cwc-color-secondary-900, #242424) !important;\n  font-family: var(--cwc-font-sans-serif-regular, 'Eina01-Regular');\n  text-decoration: none;\n  transition: color 100ms;\n}\n\n.column-2 li a > span {\n  margin-bottom: -5px;\n}\n\n.column-2 li a img {\n  margin-right: 15px;\n  flex-shrink: 0;\n}\n\n.column-2.type-2 li a h3 {\n  padding: 0;\n  font-family: var(--cwc-font-sans-serif-regular, 'Eina01-Regular');\n}\n\n.column-2.type-2 li hr {\n  display: none;\n}\n\n.column-2.type-2 li div {\n  display: none;\n}\n\n.column-2__cta {\n  padding: 0 45px;\n}\n\n.column-2__cta-content-wrapper,\n.column-2__cta-content-wrapper-with-hr {\n  padding-bottom: 30px;\n}\n\n.column-2__cta-content-wrapper-with-hr {\n  padding-top: 30px;\n  border-top: 1px solid var(--cwc-color-secondary-200, #FFCCCC);;\n}\n\n.column-2__cta-title {\n  margin-top: 0;\n  margin-bottom: 0;\n  font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n  font-weight: 400;\n  font-size: 18px;\n  color: var(--cwc-color-secondary-900, #242424) !important;\n}\n\n.column-2__cta-content {\n  margin-top: 1rem;\n  margin-bottom: 1rem;\n  display: flex;\n  gap: 15px;\n}\n\n.column-2__cta-content p {\n  margin: 0;\n}\n\n.column-2__cta-content a {\n  text-decoration: none;\n}\n\n.column-2__cta-link {\n  display: block;\n  margin-top: 64px;\n  font-size: 16.875px;\n  color: var(--cwc-color-secondary-900, #242424) !important;\n  text-decoration: none;\n}\n\n.column-2__cta-link:hover {\n  color: var(--cwc-nav-hover-text-color) !important;\n}\n\n.green-cta {\n  width: 100vw;\n  padding: 30px 45px 45px;\n  align-items: flex-start;\n  border-radius: 0;\n  text-align: left;\n  color: var(--cwc-color-white, #fff);\n  background-color: var(--cwc-nav-cta-bg, #0FC373);\n  position: relative;\n  background-image: var(--cwc-nav-cta-img-bg);\n  background-repeat: no-repeat;\n  background-position: 100% 81%;\n  background-size: 91%;\n  justify-content: var(--cwc-nav-cta-justify);\n}\n\n.green-cta .img-wrapper,\n.green-cta hr {\n  display: none;\n}\n\n.green-cta h3 {\n  margin: 0;\n  font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n  font-weight: 400;\n  font-size: 24px;\n}\n\n.green-cta p {\n  margin-bottom: 20px;\n  line-height: 1.5;\n}\n\n.green-cta .content-wrapper ul {\n  list-style-type: none;\n  padding-left: 0;\n}\n\n.green-cta a.not-button {\n  font-size: 18px;\n  font-family: var(--cwc-font-sans-serif-bold, 'Eina01-Bold');\n  font-weight: 400;\n  text-decoration: none;\n  transition: all 100ms;\n}\n\n.green-cta__description {\n  font-size: 16.875px;\n  line-height: 1.5;\n}\n\n/* Tooltip */\n[data-toggle=tooltip]{\n  display: inline;\n  position: relative;\n  justify-content: center;\n}\n[data-toggle=tooltip]:hover:after{\n  display: -webkit-flex;\n  display: flex;\n  -webkit-justify-content: center;\n  justify-content: center;\n  background: var(--cwc-color-primary, #FFAD00);\n  border-radius: 0.25rem;\n  color: var(--cwc-color-white, #fff);\n  content: attr(title);\n  position: absolute;\n  bottom: -55px;\n  white-space: pre;\n  z-index: 2;\n  padding: 15px;\n  font-size: 12px;\n  font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n  font-weight: 400;\n  max-width: 200px;\n  text-align: center;\n}\n\n[data-toggle=tooltip]:hover:before{\n  border: solid;\n  border-color: var(--cwc-color-primary, #FFAD00) transparent;\n  border-width: 8px 8px 0px;\n  content: \"\";\n  bottom: -12px;\n  position: absolute;\n  transform: rotate(180deg);\n}\n/* end Tooltip */\n\n.header-icons-wrapper__phone[data-toggle=tooltip]:hover:after{\n  font-size: 18px;\n  bottom: -57px;\n  padding: 15px 15px 9px;\n}\n\n@media (max-width: 767px) and (min-width: 320px) {\n  .header-icons-wrapper__phone[data-toggle=tooltip]:hover:after{\n    left: 0;\n  }\n  /* Nav Icons */\n  .dropdown-container .icons-wrapper {\n    justify-content: space-between;\n  }\n  .dropdown-container .header-icons-wrapper {\n      display: flex;\n      align-items: center;\n  }\n    .dropdown-container .header-icons-wrapper__phone, .dropdown-container .header-icons-wrapper__search, .dropdown-container .header-icons-wrapper__language, .dropdown-container .header-icons-wrapper__sign-in {\n      display: flex;\n      align-items: center;\n  }\n    .dropdown-container .header-icons-wrapper__phone, .dropdown-container .header-icons-wrapper__search, .dropdown-container .header-icons-wrapper__language {\n      padding: 5px;\n      margin-right: 5px;\n  }\n    .dropdown-container .header-icons-wrapper__language {\n      display: flex;\n      align-items: center;\n      justify-content: center;\n  }\n    .dropdown-container .header-icons-wrapper__language:hover .staticMap {\n      display: var( --language-icon-hover-display );\n  }\n    .dropdown-container .header-icons-wrapper__language:hover {\n      text-decoration: none !important;\n  }\n    .dropdown-container .header-icons-wrapper__language:hover .map-details svg path {\n      fill: var(--cwc-color-white, #fff);\n  }\n    .dropdown-container .header-icons-wrapper__search:hover svg circle, .dropdown-container .header-icons-wrapper__phone:hover svg path {\n      stroke: var(--cwc-color-white, #fff);\n  }\n    .dropdown-container .header-icons-wrapper__search:hover svg rect {\n      fill: var(--cwc-color-white, #fff);\n  }\n    .dropdown-container .header-icons-wrapper__phone:hover svg path {\n      fill: none !important;\n  }\n    .dropdown-container .header-icons-wrapper__language .staticMap {\n      display: block;\n      position: relative;\n      margin-left: 0;\n      height: 28px;\n      width: 28px;\n  }\n    .dropdown-container .header-icons-wrapper__language .staticMap svg:nth-child(2) {\n      position: absolute !important;\n      left: 3px !important;\n      top: 4px !important;\n      border-radius: 100%;\n  }\n    .dropdown-container .header-icons-wrapper__language .map-details {\n      display: none !important;\n  }\n\n    .dropdown-container .hidden {\n      display: none;\n  }\n    .dropdown-container .header-icons-wrapper__icon:hover {\n      color: var(--cwc-color-white, #fff) !important;\n  }\n    .dropdown-container .header-icons-wrapper__icon:hover svg g, .dropdown-container .header-icons-wrapper__icon:hover svg path {\n      fill: var(--cwc-color-white, #fff);\n  }\n    .dropdown-container .header-icons-wrapper__sign-in {\n      display: flex;\n      align-items: center;\n      margin-left: 10px;\n      color: var(--cwc-color-white, #fff) !important;\n      font-family: var(--cwc-font-sans-serif-bold, 'Eina01-Bold');\n      font-weight: 400;\n      font-size: 15px;\n      text-decoration: none;\n  }\n    .dropdown-container .header-icons-wrapper__sign-in span {\n      margin-left: 5px;\n      color: inherit;\n  }\n\n  /* end Nav Icons */\n}\n\n@media (min-width: 768px) {\n  .header__logo{\n    width: calc(328px - calc(328px * 0.20));\n  }\n  .header__logo::before{\n    margin-top: 0;\n  }\n/* Nav Icons */\n\n  .header-icons-wrapper {\n    display: flex;\n    align-items: center;\n  }\n\n  .header-icons-wrapper__phone,\n  .header-icons-wrapper__search,\n  .header-icons-wrapper__language,\n  .header-icons-wrapper__sign-in{\n    display: flex;\n    align-items: center;\n  }\n\n  .header-icons-wrapper__phone,\n  .header-icons-wrapper__search,\n  .header-icons-wrapper__language{\n    padding: 5px;\n    margin-right: 5px;\n  }\n  .header-icons-wrapper__language {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n  }\n  .header-icons-wrapper__language:hover .staticMap {\n    display: var( --language-icon-hover-display );\n  }\n  .header-icons-wrapper__language:hover .white-globe {\n    width: 28px;\n    height: 28px;\n    display: var(--language-icon-svg-hover-display);\n    background-image: url(https://cradlepoint.com/wp-content/uploads/2021/05/globe-cp__cp-yellow@4x.gif);\n    background-size: contain;\n    background-repeat: no-repeat;\n  }\n  .header-icons-wrapper__language:hover {\n    text-decoration: none !important;\n  }\n  .header-icons-wrapper__language:hover .map-details svg path {\n    fill: var(--cwc-color-white, #fff);\n  }\n\n  .header-icons-wrapper__search:hover svg circle,\n  .header-icons-wrapper__phone:hover svg path{\n  stroke: var(--cwc-color-primary, #FFAD00);\n  }\n  .header-icons-wrapper__search:hover svg rect{\n  fill: var(--cwc-color-primary, #FFAD00);\n  }\n  .header-icons-wrapper__phone:hover svg path{\n  fill: none !important;\n  }\n\n .header-icons-wrapper__language .staticMap{\n    display: block;\n    position: relative;\n    margin-left: 0;\n    height: 28px;\n    width: 28px;\n  }\n\n  .header-icons-wrapper__language .staticMap svg:nth-child(2) {\n    position: absolute!important;\n    left: 3px!important;\n    top: 4px!important;\n    border-radius: 100%;\n  }\n\n  .header-icons-wrapper__language .map-details{\n    margin-left: 10px;\n    flex-grow: 0;\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    align-items: flex-start;\n    gap: 3px;\n    padding: 0;\n  }\n\n  .header-icons-wrapper__language .map-details p{\n    font-size: 14px;\n    font-family: var(--cwc-font-sans-serif-bold, 'Eina01-Bold');\n    font-weight: 400;\n    line-height: normal;\n    letter-spacing: normal;\n    text-align: left;\n    color: var(--cwc-color-white, #fff);\n    margin-bottom: 0;\n    margin-top: 0;\n    display: flex;\n    align-items: center;\n  }\n  .header-icons-wrapper__language .map-details span{\n    font-size: 13px;\n    font-weight: 600;\n    font-stretch: normal;\n    font-style: normal;\n    line-height: normal;\n    letter-spacing: normal;\n    text-align: left;\n    color: #adb2b5;\n    font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n    font-weight: 400;\n  }\n\n  .header-icons-wrapper__language .map-details svg{\n    margin-left: 5px;\n    fill: var(--cwc-color-white, #fff);\n    width: 14px;\n  }\n\n  .hidden{\n    display: none;\n  }\n\n  /* .header-icons-wrapper__icon:hover {\n    color: var(--cwc-color-primary, #FFAD00) !important;\n  } */\n\n  .header-icons-wrapper__icon:hover svg g,\n  .header-icons-wrapper__icon:hover svg path {\n    fill: var(--cwc-color-primary, #FFAD00);\n  }\n\n  .header-icons-wrapper__sign-in {\n    display: flex;\n    align-items: center;\n    margin-left: 10px;\n    color: var(--cwc-color-white, #fff) !important;\n    font-family: var(--cwc-font-sans-serif-bold, 'Eina01-Bold');\n    font-weight: 400;\n    font-size: 15px;\n    text-decoration: none;\n  }\n\n  .header-icons-wrapper__sign-in span {\n    margin-left: 5px;\n    color: inherit;\n  }\n\n/* end Nav Icons */\n\n  .icons-wrapper {\n    display: none;\n  }\n\n  .column-1-container {\n    flex-shrink: 0;\n    width: clamp(250px, 35%, 270px);\n  }\n\n  .column-1 {\n    width: 100%;\n    height: 100%;\n    padding-top: 36px;\n    padding-bottom: 36px;\n    font-size: 15px;\n    background-color: var(--cwc-nav-left-column-bg, #e6e8e8);\n  }\n\n  .column-1 li {\n    border-bottom: 0;\n  }\n\n  .column-1 li a {\n    padding-left: 12px;\n    padding-right: 12px;\n    font-size: var(--cwc-nav-left-column-font-size, 18px);\n    text-transform: var(--cwc-nav-left-column-text-transform, uppercase);\n  }\n\n  .column-1 li a.active {\n    font-family: var(--cwc-font-sans-serif-bold, 'Eina01-Bold');\n    font-weight: 400;\n    background-color: var(--cwc-color-white, #fff);\n  }\n\n  .green-cta.green-cta__mobile-default {\n    display: none;\n  }\n\n  .column-2-3__container {\n    width: auto;\n  }\n\n  .column-2-3__item {\n    justify-content: space-between;\n    height: 100%;\n  }\n\n  .mid-container {\n    flex-grow: 1;\n    background-color: var(--cwc-color-white, #fff);\n  }\n\n  .mid-container .sub-title {\n    display: none;\n  }\n\n  .column-2 {\n    display: grid;\n    grid-template-columns: repeat(2,1fr);\n    grid-column-gap: 32px;\n    grid-row-gap: 45px;\n    height: fit-content;\n    padding: 60px 35px 36px;\n    background-color: var(--cwc-color-white, #fff);\n    font-size: 15px;\n  }\n\n  .column-2 li hr {\n    width: 25px;\n    height: 4px;\n    margin: 8.5px auto 8.5px 0;\n    background-color: var(--cwc-nav-cta-bg, #0FC373);\n    border: 2px solid var(--cwc-nav-cta-bg, #0FC373);\n    border-radius: 4px;\n    box-sizing: border-box\n  }\n\n  .column-2 h3 {\n    margin-top: 0;\n    margin-bottom: 1.65rem;\n    padding: 0;\n    font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n    font-weight: 400;\n    font-size: 15px;\n    line-height: 16.875px;\n    color: var(--cwc-color-secondary-900, #242424) !important;\n  }\n\n  .column-2 li a {\n    padding: 0;\n    font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n    font-weight: 400;\n  }\n\n  .column-2 li a:hover {\n    color: var(--cwc-nav-hover-text-color) !important;\n  }\n\n  .column-2.type-2 h3 {\n    margin: 0;\n    transition: all 100ms;\n  }\n\n  .column-2.type-2 a:hover h3 {\n    color: var(--cwc-nav-hover-text-color) !important;\n  }\n\n  .column-2.type-2 ul {\n    margin-top: 25px;\n  }\n\n  .column-2.type-2 li a h3 {\n    font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n    font-weight: 400;\n  }\n\n  .column-2.type-2 p {\n    font-family: var(--cwc-font-sans-serif-regular, 'Eina01-Regular');\n    font-size: 13px;\n    line-height: 19.5px;\n  }\n\n  .column-2 .has-sub-menu .sub-menu {\n    padding-left: 0;\n    display: grid;\n    row-gap: 1.65rem;\n  }\n\n  .column-2 .has-sub-menu .sub-menu li a {\n    font-family: var(--cwc-font-sans-serif-light, 'Eina01-Light');\n  }\n\n  .column-2__cta {\n    padding-left: 35px;\n    padding-right: 35px;\n  }\n\n  .column-2__cta-title {\n    font-size: 15px;\n    line-height: 16.875px;\n    color: var(--cwc-color-secondary-900, #242424) !important;\n  }\n\n  .column-2__cta-content {\n    font-size: 14px;\n  }\n\n  .column-2__cta-link {\n    font-size: 15px;\n  }\n\n  .green-cta {\n    display: flex;\n    flex-direction: row;\n    gap: 2rem;\n    width: auto;\n    height: fit-content;\n    padding: 36px 35px;\n    font-size: 15px;\n    line-height: 22.5px;\n  }\n\n  .green-cta .img-wrapper {\n    flex-shrink: 0;\n    display: grid;\n    place-items: center;\n    border-radius: 50%;\n    background-color: var(--cwc-color-secondary, #333F48);\n    height: 64px;\n    width: 64px;\n    padding: 15px;\n    margin-left: auto;\n    margin-right: auto;\n  }\n\n  .green-cta .img-wrapper img {\n    width: 100%;\n    height: auto;\n    object-fit: contain;\n  }\n\n  .green-cta hr {\n    width: 50px;\n    height: 4px;\n    margin-top: 12px;\n    margin-bottom: 12px;\n    margin-left: 0;\n    background-color: var(--cwc-color-white, #fff);\n    border: 2px solid var(--cwc-color-white, #fff);\n    border-radius: 4px;\n  }\n\n  .green-cta h3 {\n    font-family: var(--cwc-font-sans-serif-semibold, 'Eina01-SemiBold');\n    font-weight: 400;\n    margin-top: 0;\n  }\n\n  .green-cta a.not-button:hover {\n    color: var(--cwc-color-secondary-900, #242424) !important;\n    text-decoration: underline;\n  }\n}\n\n@media (min-width: 1025px) {\n  .header__logo::before{\n    margin-top: -4px;\n  }\n\n  .header-inner__left {\n    gap: 1.25rem;\n  }\n\n  .header__logo{\n    width: unset;\n  }\n\n  /* Nav Icons */\n  .header-icons-wrapper__phone,\n  .header-icons-wrapper__search,\n  .header-icons-wrapper__language{\n    padding: 10px;\n    margin-right: 10px;\n    text-decoration: none;\n  }\n  .header-icons-wrapper__sign-in {\n    margin-left: 35px;\n  }\n\n  .header-icons-wrapper__sign-in span {\n    margin-left: 12px;\n  }\n  /* Nav Icons */\n\n  :host(.active) header {\n    /* border-bottom: 15px solid var(--cwc-nav-toggle-active-background-color, #FFAD00); */\n  }\n\n  .header-inner {\n    padding-left: 48px;\n    padding-right: 48px;\n  }\n\n  .nav-toggle {\n    padding-block: 0;\n  }\n\n  .dropdown-container {\n    top: 60px;\n    left: 48px;\n    max-width: calc(100vw - 96px);\n    height: 0;\n    overflow: hidden;\n    border-radius: 0 0 16px 16px;\n    background-color: transparent;\n  }\n\n  .dropdown-container,\n  :host(.active) .dropdown-container {\n    transform: unset;\n  }\n\n  :host(.active) .dropdown-container {\n    height: initial;\n  }\n\n  .column-1-container {\n    width: 21.30%;\n  }\n\n  .column-2-3__container {\n    display: flex;\n    width: 78.7%;\n    background-color: transparent;\n  }\n\n  .column-2-3__item {\n    flex-direction: row;\n    width: 100%;\n    max-width: 1180px;\n  }\n\n  .mid-container {\n    display: flex;\n    flex-direction: column;\n    width: 66.57%;\n  }\n\n  .column-2 {\n    grid-column-gap: 35px;\n    grid-row-gap: 65px;\n  }\n\n  .column-2 > li.has-border-right {\n    border-right: 1px solid var(--cwc-color-secondary-200, #FFCCCC);\n  }\n\n  .column-2.type-2 li hr,\n  .column-2.type-2 li div {\n    display: block;\n  }\n\n  .column-2__cta {\n    flex-grow: 1;\n  }\n\n  .column-2__cta > div {\n    display: flex;\n    flex-direction: column;\n    height: 100%;\n    min-height: 200px;\n  }\n\n  .column-2__cta-link {\n    margin-bottom: 0px;\n    margin-top: auto;\n  }\n\n  .green-cta {\n    flex-direction: column;\n    gap: 0;\n    width: 33.43%;\n    height: auto;\n    text-align: center;\n    border-radius: 0 0 16px 0;\n  }\n\n  .green-cta .img-wrapper {\n    height: 82px;\n    width: 82px;\n  }\n\n  .green-cta h3 {\n    margin-top: 15px;\n  }\n\n  .green-cta hr {\n    margin-top: 23px;\n    margin-bottom: 23px;\n    margin-left: auto;\n  }\n\n  .green-cta p {\n    margin-bottom: 40px;\n  }\n}\n\n@media (min-width: 1280px) {\n  .column-1 {\n    font-size: 16.5px;\n  }\n\n  .column-2.one-third--two-thirds {\n    grid-template-columns: 1.5fr 3fr;\n  }\n\n  .column-2.one-third--two-thirds .has-sub-menu:last-child .sub-menu {\n    grid-template-columns: repeat(2, 1fr);\n    grid-column-gap: 35px;\n  }\n\n  .column-2__cta-link {\n    font-size: 16.5px;\n  }\n}\n\n@media (min-width: 1440px) {\n  .column-1 {\n    padding-top: 52px;\n    padding-bottom: 52px;\n    font-size: 18px;\n  }\n\n  .column-1 li a {\n    padding-left: 45px;\n    padding-right: 20px;\n  }\n\n  .column-2 {\n    padding-top: 72px;\n    padding-bottom: 52px;\n    grid-template-columns: repeat(3,1fr);\n    font-size: 16px;\n  }\n\n  .column-2.two-columns {\n    grid-template-columns: repeat(2,1fr);\n  }\n\n  .column-2 h3,\n  .column-2__cta-title {\n    font-size: 18px;\n    line-height: 20.25px;\n  }\n\n  .column-2__cta-content {\n    font-size: 16px;\n  }\n\n  .column-2__cta-link {\n    font-size: 18px;\n  }\n\n  .green-cta h3 {\n    font-size: 22px;\n  }\n\n  .green-cta p {\n    font-size: 18px;\n    line-height: 27px;\n  }\n\n  .green-cta a.not-button {\n    font-size: 24px;\n  }\n}\n\n@media (min-width: 1550px) {\n  .column-1-container {\n    width: 21.29%;\n  }\n\n  .column-2-3__container {\n    width: 78.70%;\n  }\n}\n\n/*\n\n  Mobile Menu\n\n*/\n\nheader.mobile {\n  --transition: all 100ms;\n}\n\nheader.mobile .dropdown-container {\n  height: 100vh;\n  transition: var(--transition);\n}\n\nheader.mobile .column-1-container,\nheader.mobile .column-2-3__container {\n  position: absolute;\n  transition: var(--transition);\n}\n\nheader.mobile .column-1-container {\n  transform: translateX(0);\n}\n\nheader.mobile .column-1 li a {\n  padding-top: 8px;\n}\n\nheader.mobile .column-1 li a svg {\n  margin-bottom: 5px;\n}\n\nheader.mobile.level-2 .column-1-container {\n  transform: translateX(-100vw);\n}\n\nheader.mobile.level-3 .column-1-container {\n  transform: translateX(-200vw);\n}\n\nheader.mobile .column-2-3__container {\n  transform: translateX(100vw);\n}\n\nheader.mobile.level-2 .column-2-3__container {\n  transform: translateX(0);\n}\n\nheader.mobile.level-3 .column-2-3__container  {\n  transform: translateX(-100vw);\n}\n\nheader.mobile .column-2-3__container .mid-container .sub-title span {\n  padding-top: 3px;\n  margin-bottom: -3px;\n}\n\nheader.mobile .column-2 > li {\n  position: relative;\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu {\n  display: none;\n  position: absolute;\n  width: 100vw;\n  transform: translateX(100vw);\n  background-color: var(--cwc-color-white, #fff);\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu.active {\n  display: block;\n}\n\nheader.mobile .column-2 .has-sub-menu:first-child .sub-menu {\n  top: -77px;\n}\n\nheader.mobile .column-2 .has-sub-menu:nth-child(2) .sub-menu {\n  top: calc((30px + (49px * 2)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu:nth-child(3) .sub-menu {\n  top: calc((30px + (49px * 3)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu:nth-child(4) {\n  top: calc((30px + (49px * 4)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu:nth-child(5) {\n  top: calc((30px + (49px * 5)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu:nth-child(6) {\n  top: calc((30px + (49px * 6)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu:nth-child(7) {\n  top: calc((30px + (49px * 7)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu:nth-child(8) {\n  top: calc((30px + (49px * 8)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu:nth-child(9) {\n  top: calc((30px + (49px * 9)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu:nth-child(10) {\n  top: calc((30px + (49px * 10)) * (-1));\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu li {\n  background-color: rgb(230, 232, 232);\n}\n\nheader.mobile .column-2 .has-sub-menu .sub-menu li a {\n  padding-top: 22.5px;\n  padding-bottom: 22.5px;\n}\n\nheader.mobile .column-2 li a img {\n  display: none;\n}\n\n/*\n\n  Alt Mobile Layout\n\n*/\n\nheader.mobile.alt-mobile-layout .column-2 > li {\n  position: unset;\n}\n\nheader.mobile.alt-mobile-layout .column-2 .has-sub-menu .sub-menu {\n  display: block;\n  position: unset;\n  width: unset;\n  transform: unset;\n  background-color: unset;\n}\n\nheader.mobile.alt-mobile-layout .column-2 .has-sub-menu .sub-menu .sub-title  {\n  display: none;\n}\n\nheader.mobile.alt-mobile-layout .column-2 .has-sub-menu .sub-menu li a {\n  font-family: var(--cwc-font-sans-serif-regular, 'Eina01-Regular');\n  padding-top: 14px;\n  padding-bottom: 12px;\n}\n\nheader.mobile.alt-mobile-layout .column-2 li.has-sub-menu:not(:first-child) {\n  margin-top: 24px;\n}\n\nheader.mobile.alt-mobile-layout .column-2 li a {\n  padding-top: 14px;\n  padding-bottom: 12px;\n}\n\nheader.mobile.alt-mobile-layout .column-2 li a img {\n  display: block;\n}\n\nheader .globe-icon::before{\n  content: '';\n  display: block;\n  -webkit-mask: var(--language-icon) no-repeat 50% 50%;\n  mask: var(--language-icon) no-repeat 50% 50%;\n  -webkit-mask-size: cover;\n  mask-size: cover;\n  height: 28px;\n  width: 28px;\n  background-color: #fff;\n}\n\n.header-icons-wrapper__language:hover .globe-icon::before{\n  background-color: var(--language-icon-hover-bg);\n}\n.dropdown-container .header-icons-wrapper__language:hover .globe-icon::before{\n  background-color: var(--cwc-color-white);\n}\n\ncradlepoint-button-cta {\n  clip-path: unset;\n  border-radius: 4px;\n  text-transform: unset;\n\n  &::before {\n    display: none;\n  }\n}\n";
const CradlepointNavMainStyle0 = navMainCss;

const NavMain = /*@__PURE__*/ proxyCustomElement(class NavMain extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.loaded = false;
        this.isActive = false;
        this.jsonData = null;
        this.showIconsWrapper = false;
        this.getPhoneSVG = (className, fillColor = '#fff') => {
            return (h("svg", { class: className, xmlns: "http://www.w3.org/2000/svg", width: 29, height: 29, preserveAspectRatio: "xMidYMid meet", viewBox: "0 0 16 16", style: { transform: 'rotate(360deg)' } }, h("path", { fill: "none", stroke: fillColor, "stroke-linecap": "round", "stroke-linejoin": "round", "stroke-width": "1.5", d: "M1.75 1.75c0 8.5 4 12.5 12.5 12.5v-4l-3.5-1l-1 1.5c-2 0-4.5-2.5-4.5-4.5l1.5-1l-1-3.5zm8 0c2.5 0 4.5 2 4.5 4.5m-4.5-2c1 0 2 1 2 2" })));
        };
        this.getSearchSVG = (className, fillColor = '#fff') => {
            return (h("svg", { class: className, width: 29, height: 29, viewBox: "0 0 29 29", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, h("circle", { cx: "11", cy: "11", r: "9.5", stroke: fillColor, "stroke-width": "3" }), h("rect", { x: "16", y: "19.614", width: "5", height: "13", transform: "rotate(-46.2862 16 19.614)", fill: fillColor })));
        };
        this.getSignInSVG = (fillColor = 'white') => {
            return (h("svg", { style: { width: '18px' }, "data-name": "Layer 1", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 15 16" }, h("path", { style: { strokeWidth: '0px', fill: fillColor }, class: "cls-1", fill: fillColor, "fill-rule": 'evenodd', d: "M6,0v4h-1V1H1v14h4v-3h1v4H0V0h6ZM9.65,13.35l-5.35-5.36,5.35-5.35.65.71-4.14,4.15h8.84v1H6.21l4.09,4.14-.65.71Z" })));
        };
        this.getAngleRightSVG = () => {
            return (h("svg", { xmlns: "http://www.w3.org/2000/svg", height: "16", width: "10", viewBox: "0 0 320 512" }, h("path", { d: "M278.6 233.4c12.5 12.5 12.5 32.8 0 45.3l-160 160c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3L210.7 256 73.4 118.6c-12.5-12.5-12.5-32.8 0-45.3s32.8-12.5 45.3 0l160 160z" })));
        };
        this.getLinkClass = (title, subtitle) => {
            let linkClass = `${title} ${subtitle}`;
            return linkClass.replace('-', '_').toLowerCase().split(' ').join('_');
        };
        this.toggleNav = (event) => {
            var _a, _b;
            event.preventDefault();
            let sr = this.host.shadowRoot;
            let header = sr.querySelector('header');
            this.isActive = !this.isActive;
            this.host.classList.toggle('active');
            if (document.querySelector('body #modal-backDrop')) {
                document.querySelector('body #modal-backDrop').remove();
            }
            if (this.host.classList.contains('active')) {
                let backDrop = document.createElement('div');
                backDrop.setAttribute("id", "modal-backDrop");
                document.querySelector('body').appendChild(backDrop);
            }
            if (!this.isActive) {
                setTimeout(() => {
                    header.classList.remove('level-2', 'level-3', 'level-4');
                }, 150);
            }
            (_a = document.querySelector(`${this.searchForm}`)) === null || _a === void 0 ? void 0 : _a.classList.add('hidden');
            (_b = document.querySelector(`${this.navLang}`)) === null || _b === void 0 ? void 0 : _b.classList.add('hidden');
        };
        this.switchColumn2 = (event) => {
            let sr = this.host.shadowRoot;
            let el = event.composedPath()[0];
            let col1As = sr.querySelectorAll('.column-1 li a');
            let col23Items = sr.querySelectorAll('.column-2-3__item');
            let newActiveItem = sr.querySelector(`.column-2-3__item[data-target-name="${el.dataset.target}"]`);
            let header = sr.querySelector('header');
            col1As.forEach(item => item.classList.remove('active'));
            el.classList.add('active');
            col23Items.forEach(item => item.classList.remove('active'));
            newActiveItem.classList.add('active');
            header.classList.contains('mobile') && header.classList.add('level-2');
        };
        this.switchColumn3 = (event) => {
            event.preventDefault();
            let sr = this.host.shadowRoot;
            let el = event.composedPath()[0];
            let newActiveItem = sr.querySelector(`.sub-menu[data-target-name="${el.dataset.target}"]`);
            let header = sr.querySelector('header');
            if (header.classList.contains('mobile')) {
                header.classList.remove('level-2');
                header.classList.add('level-3');
                newActiveItem.classList.add('active');
            }
        };
        this.backToLevel1 = () => {
            let sr = this.host.shadowRoot;
            let header = sr.querySelector('header');
            header.classList.contains('mobile') && header.classList.remove('level-2');
        };
        this.backToLevel2 = () => {
            let sr = this.host.shadowRoot;
            let header = sr.querySelector('header');
            let level3Items = header.querySelectorAll('.column-2 .has-sub-menu .sub-menu');
            header.classList.contains('mobile') && header.classList.remove('level-3');
            header.classList.contains('mobile') && header.classList.add('level-2');
            let level3ItemsTimeout = setTimeout(() => {
                level3Items.forEach(item => {
                    item.classList.remove('active');
                });
                clearTimeout(level3ItemsTimeout);
            }, 500);
        };
        this.toggleSearch = (event) => {
            var _a, _b;
            event.preventDefault();
            this.host.classList.remove('active');
            if (!document.querySelector(`${this.searchForm ? this.searchForm : '.search-form-div'}`).classList.contains('hidden')) {
                if (document.querySelector('body #modal-backDrop')) {
                    document.querySelector('body #modal-backDrop').remove();
                }
            }
            else {
                if (document.querySelector('body #modal-backDrop')) {
                    document.querySelector('body #modal-backDrop').remove();
                }
                let backDrop = document.createElement('div');
                backDrop.setAttribute("id", "modal-backDrop");
                document.querySelector('body').appendChild(backDrop);
            }
            (_a = document.querySelector(`${this.searchForm ? this.searchForm : '.search-form-div'}`)) === null || _a === void 0 ? void 0 : _a.classList.toggle('hidden');
            (_b = document.querySelector(`${this.navLang}`)) === null || _b === void 0 ? void 0 : _b.classList.add('hidden');
        };
        this.toggleNavLang = (event) => {
            var _a, _b;
            event.preventDefault();
            if (document.querySelector('body #modal-backDrop')) {
                document.querySelector('body #modal-backDrop').remove();
            }
            if (this.host.querySelector('cradlepoint-nav-lang').classList.contains('hidden')) {
                let backDrop = document.createElement('div');
                backDrop.setAttribute("id", "modal-backDrop");
                document.querySelector('body').appendChild(backDrop);
            }
            this.host.classList.remove('active');
            (_a = document.querySelector(`${this.navLang}`)) === null || _a === void 0 ? void 0 : _a.classList.remove('hidden');
            (_b = document.querySelector(`${this.searchForm ? this.searchForm : '.search-form-div'}`)) === null || _b === void 0 ? void 0 : _b.classList.add('hidden');
        };
        this.domain = 'cradlepoint.com';
        this.json = undefined;
        this.logo = 'https://img.cradlepoint.com/auto-mapping-folder/2022/07/cradlepoint-po-ericsson-logo-long-reverse.png';
        this.logoLight = undefined;
        this.logoDark = undefined;
        this.searchForm = undefined;
        this.navLang = undefined;
        this.showContact = false;
        this.showSearch = false;
        this.showLanguageNav = false;
        this.showSignIn = false;
        this.altMobileLayout = false;
        this.countryCode = undefined;
        this.activeLang = undefined;
        this.phoneNo = undefined;
        this.homeLink = undefined;
        this.hoverTextColor = '#1174e6';
    }
    async componentWillLoad() {
        if (this.showContact || this.showSearch || this.showLanguageNav || this.showSignIn) {
            this.showIconsWrapper = true;
        }
        if (this.json) {
            return fetch(this.json)
                .then(response => response.json())
                .then(data => {
                this.jsonData = data;
                this.loaded = true;
            })
                .catch(error => console.log(error));
        }
        return null;
    }
    componentDidLoad() {
        (window.innerWidth < 767) && this.host.shadowRoot.querySelector('header').classList.add('mobile');
    }
    handleResize() {
        clearTimeout(resizeTimeout);
        var resizeTimeout = setTimeout(() => {
            if (window.innerWidth < 768) {
                this.host.shadowRoot.querySelector('header').classList.add('mobile');
            }
            else {
                this.host.shadowRoot.querySelector('header').classList.remove('mobile');
            }
        }, 100);
    }
    render() {
        return (h(Host, { key: 'bee7480963fc100472ae8c818dc7c675518f04a8', class: this.loaded ? 'loaded' : '', style: {
                '--cwc-nav-hover-text-color': this.hoverTextColor,
            } }, this.jsonData && (h("header", { key: 'd9bee90c043f24c7a727f2b6e7aed34d0d2061c7', class: this.altMobileLayout == true ? 'alt-mobile-layout' : '' }, h("div", { key: 'af68b9c7351c42058bfd7899886c42df73e4bf90', class: "header-inner" }, h("div", { key: '6524f5b794d2b43da5695d6d5262f3d453b8555e', class: "header-inner__left" }, h("button", { key: 'a00cd294415950e3bd62a51c356b8c3a33d239fd', class: "nav-toggle", "aria-expanded": this.isActive, "aria-label": "Toggle navigation", onClick: this.toggleNav }, h("slot", { key: '593e5925dee322b2551667f5eb756ee8e8cdc73a', name: "icon-toggle-nav" })), h("a", { key: '3bf1b6d1d533a1530077819743abd519ad276667', href: this.homeLink ? this.homeLink : '/', class: "header__logo header__home-link" }, h("slot", { key: 'de2e7e33fb768a7dbe14d91be9345023facfd407', name: "header-logo" }))), this.showIconsWrapper && (h("div", { key: '3af0ba3e6cf5581b8398da2733cac2695e3e6994', class: "header-icons-wrapper" }, (this.showContact && this.phoneNo) && (h("a", { key: '9033725a12cc7f0eae7c3eb113cd403c8c8d567d', href: 'tel:' + this.phoneNo, class: 'header-icons-wrapper__icon header-icons-wrapper__phone', "data-toggle": "tooltip", title: this.phoneNo }, h("slot", { key: '11e48e32e486fb6a2e7e9973e48861ffaa2fcf36', name: "icon-phone" }))), this.showSearch && (h("a", { key: '8dc22a1a1b316b9f231a3de9fe645c6e8c0f0966', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__search', onClick: this.toggleSearch }, h("slot", { key: '6a36b85c6cda2856bcb7fcb2956fc3c1613aabb4', name: "icon-search" }))), this.showLanguageNav && (h("a", { key: 'a4940cd32e790de9f4359b546f5aab800ca05cba', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__language', onClick: this.toggleNavLang }, h("slot", { key: '58d33629b090d837698860bf36e1d92d84fa3ead', name: "icon-globe" }), h("div", { key: '5f91026d6e5a90cc410200651996a77b835aaa7d', class: 'map-details' }, h("p", { key: 'c6817e26bc1eab162ee12db01e77cf502e62a3e7' }, this.countryCode, " ", h("svg", { key: '44cfecd7b25bfab98a5f81357d5770c6ba0fe92d', class: 'svg-inline--fa fa-angle-down', "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "angle-down", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 448 512", "data-fa-i2svg": "" }, h("path", { key: 'cd5eaaa602ca6d0576ed5231342daaed9d1a5a10', fill: "currentColor", d: "M201.4 342.6c12.5 12.5 32.8 12.5 45.3 0l160-160c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L224 274.7 86.6 137.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l160 160z" }))), h("span", { key: '93ceb8fa7d56889eb86d59228593d60a035ccb78' }, this.activeLang)))), this.showSignIn && (h("a", { key: '67276e37a5169f0608b9b2122e4b13397f44c1b4', href: "/sign-in", class: 'header-icons-wrapper__icon header-icons-wrapper__sign-in' }, this.getSignInSVG('white'), h("span", { key: 'e0d668d3e96a713c508c3668e9a6f82c407d421c' }, "SIGN IN")))))), h("div", { key: '0ff6492b068a72efb4047f1b926e77920d2139fe', class: "dropdown-container" }, h("div", { key: 'edf5c2307ae946c6f1e283d0d39f6d9bd3d47817', class: "column-1-container" }, this.showIconsWrapper && (h("div", { key: '66f248cde727c5910971e2098c85461da296f0ea', class: "icons-wrapper" }, (this.showContact && this.phoneNo) && (h("a", { key: 'fca537f50e4d42e96f75aa602bcea5a829f768b5', href: 'tel:' + this.phoneNo, class: 'header-icons-wrapper__icon header-icons-wrapper__phone', "data-toggle": "tooltip", title: this.phoneNo }, h("slot", { key: 'a3473b1150bfa9892d017f2afe9398b8372a84ae', name: "icon-phone-mobile" }))), this.showSearch && (h("a", { key: 'b2f81a7e9659d6beda25ecf61f74b46b8c3ddbe6', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__search', onClick: this.toggleSearch }, h("slot", { key: 'c84a6cb0b04e4c4b27ba9c63019b0831498626b5', name: "icon-search-mobile" }))), this.showLanguageNav && (h("a", { key: 'd8fd037181069f4c4d8e6caf3d0338bafa34fa39', href: '#', class: 'header-icons-wrapper__icon header-icons-wrapper__language', onClick: this.toggleNavLang }, h("slot", { key: 'f399cb40a3cf8c1d12a82af2f82411b216e81d9a', name: "icon-globe-mobile" }), h("i", { key: '309e9648d87840f3e62d9c9e1526f4a18313e7e0', class: 'languageFlags white-globe hidden' }), h("div", { key: '5d6841c01fc795c5f7894945ac6eab6eb6445952', class: 'map-details' }, h("p", { key: '96e95fa0d575d35ced9b7078acc82b8d2b39a830' }, this.countryCode, " ", h("svg", { key: '6b5b620a39e3a81470cdba61842f043083123985', class: 'svg-inline--fa fa-angle-down', "aria-hidden": "true", focusable: "false", "data-prefix": "fas", "data-icon": "angle-down", role: "img", xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 448 512", "data-fa-i2svg": "" }, h("path", { key: '2149061e5486adc159e48b3cb71d6005e2029476', fill: "currentColor", d: "M201.4 342.6c12.5 12.5 32.8 12.5 45.3 0l160-160c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L224 274.7 86.6 137.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l160 160z" }))), h("span", { key: 'd033040acc5683261ef1e054ac26ad2a7998941c' }, this.activeLang)))), this.showSignIn && (h("a", { key: '8265fb99dc6e19babae03037f0d573538b4c662e', href: "/sign-in", class: 'header-icons-wrapper__icon header-icons-wrapper__sign-in' }, this.getSignInSVG('white'))))), h("ul", { key: '85bc0f3f7a642f2e39fad6190be975f18f12ebdc', class: "dropdown-column column-1 list-none" }, this.jsonData.main_navigation_v2.map((item, index) => {
            return (h("li", null, h("a", { href: "#", "data-target": (item.title.toLowerCase()).split(' ').join('-'), class: `nav_${(item.title.toLowerCase()).split(' ').join('_')} ${index == 0 ? 'active' : ''}`, onClick: this.switchColumn2 }, h("span", null, item.title), " ", this.getAngleRightSVG())));
        })), this.jsonData.main_navigation_v2[0]['cta'] && (h("div", { key: 'f5ccd0f8f994a6be72a7bad5957397d4854931cf', class: "column-3 type-2 green-cta green-cta__mobile-default" }, h("div", { key: '5a534c60a36f27e83cb3df941509af6b7264f2c9', class: "content-wrapper" }, this.jsonData.main_navigation_v2[0]['cta']['title'] && (h(Fragment, { key: '55857d92da982300a8127b50713778209b495de3' }, h("h3", { key: 'e9207d98254fa8ddb519457f9ed258ebe0e6769b', class: "green-cta__title" }, this.jsonData.main_navigation_v2[0]['cta']['title']))), this.jsonData.main_navigation_v2[0]['cta']['short_description'] && h("p", { key: '1cf4577a1627691732020cf1d5f0cb136e034aff', class: "green-cta__description" }, this.jsonData.main_navigation_v2[0]['cta']['short_description']), this.jsonData.main_navigation_v2[0]['cta']['button_type'] == 'v1' && this.jsonData.main_navigation_v2[0]['cta']['button'] && (h("cradlepoint-button-cta", { key: '187305bdb633da6fe184ac9ce58e3a9efc2b5bff', link: formatHREF(this.domain, this.jsonData.main_navigation_v2[0]['cta']['button']['url']) }, this.jsonData.main_navigation_v2[0]['cta']['button']['title'])), this.jsonData.main_navigation_v2[0]['cta']['button_type'] == 'v2' && this.jsonData.main_navigation_v2[0]['cta']['buttons'] && (h("ul", { key: '9f7e3afb2a3f87f73701f2d43d312e0416c6fe51' }, this.jsonData.main_navigation_v2[0]['cta']['buttons'].map((button) => {
            return (h("li", { class: "no-icon" }, h("a", { href: formatHREF(this.domain, button['button']['url']), target: "_self", class: "not-button" }, button['button']['title'])));
        }))))))), h("div", { key: '497b21608f2abfcb2238e9f84c4631e7528b4f66', class: "dropdown-column column-2-3__container" }, this.jsonData.main_navigation_v2.map((item, index) => {
            return (h("div", { class: `column-2-3__item ${index == 0 ? 'active' : ''}`, "data-target-name": (item.title.toLowerCase()).split(' ').join('-') }, h("div", { class: "mid-container" }, h("a", { href: "#", class: "sub-title", onClick: this.backToLevel1 }, this.getAngleRightSVG(), h("span", null, item.title)), item.modules.length > 0 && item.modules.map((module) => {
                if (module.acf_fc_layout == 'cta') {
                    let { hr, icon, short_description, title, link } = module;
                    return (h("div", { class: `column-2__cta` }, h("div", { class: `column-2__cta-content-wrapper${hr ? '-with-hr' : ''}` }, title && h("h3", { class: "column-2__cta-title" }, title), (icon || short_description) && (h("div", { class: "column-2__cta-content" }, icon && h("img", { src: icon, alt: "icon", width: "23", height: "23" }), short_description && (h("div", { style: {
                            color: 'var(--cwc-color-secondary-900, #242424)'
                        }, innerHTML: short_description })))), link && (h("a", { class: "column-2__cta-link", href: formatHREF(this.domain, link.url), target: link.target ? link.target : '_self' }, link.title)))));
                }
                else {
                    let ulClass = `column-2 list-none _nav_v2_${item.modules[0].acf_fc_layout}`;
                    switch (item.modules[0].acf_fc_layout) {
                        case 'link_title_description_repeater':
                            ulClass += ' type-2';
                            break;
                        default:
                            ulClass += ' type-1';
                            break;
                    }
                    switch (item.modules[0].columns) {
                        case "1/3-2/3":
                            ulClass += ' one-third--two-thirds';
                            break;
                        case "2":
                            ulClass += ' two-columns';
                            break;
                    }
                    return (h("ul", { class: `${ulClass}` }, (module.acf_fc_layout == 'icon_title_repeater') && module.data.map((subItem) => {
                        return (h("li", null, subItem.show_link && h(Fragment, null, h("a", { href: formatHREF(this.domain, subItem.link.url), class: this.getLinkClass(item.title, subItem.link.title) }, subItem.icon && h("img", { src: subItem.icon, alt: `${subItem.link.title} icon`, width: "23", height: "23" }), h("span", null, subItem.link.title))), !subItem.show_link && h(Fragment, null, h("h3", null, subItem.link.title))));
                    }), (module.acf_fc_layout == 'link_title_description_repeater') && module.data.map((subItem) => {
                        let liClass, titleHTML;
                        let dataTarget = subItem.title.toLowerCase().split(' ').join('_');
                        liClass = '';
                        if (subItem.border_right == true) {
                            liClass += ' has-border-right';
                        }
                        if (subItem.icon_link_repeater.length) {
                            liClass += ' has-sub-menu';
                        }
                        if (subItem.link_title) {
                            titleHTML = (h("a", { href: formatHREF(this.domain, subItem.link.url), target: "_self", class: this.getLinkClass(item.title, subItem.link.title) }, h("h3", null, subItem.link.title)));
                        }
                        else {
                            titleHTML = h("h3", { "data-target": dataTarget, onClick: this.switchColumn3 }, subItem.title);
                        }
                        return (h("li", { class: liClass }, titleHTML, subItem.short_description && h(Fragment, null, h("div", { innerHTML: subItem.short_description })), subItem.icon_link_repeater.length && h(Fragment, null, h("ul", { class: "list-none sub-menu", "data-target-name": dataTarget }, h("a", { href: "#", class: "sub-title", onClick: this.backToLevel2 }, this.getAngleRightSVG(), h("span", null, subItem.title)), subItem.icon_link_repeater.map((iconLinkRepeaterItem) => {
                            return (h("li", null, h("a", { href: formatHREF(this.domain, iconLinkRepeaterItem.link.url), target: "_self", class: this.getLinkClass(item.title, iconLinkRepeaterItem.link.title) }, iconLinkRepeaterItem.icon && h("img", { src: iconLinkRepeaterItem.icon, alt: "Fixed sites icon", width: "23", height: "23" }), h("span", null, iconLinkRepeaterItem.link.title))));
                        })))));
                    })));
                }
            })), item['cta'] && (h("div", { class: "type-2 green-cta" }, item['cta']['icon'] && (h("div", { class: "img-wrapper" }, h("img", { src: item['cta']['icon'], alt: "icon", width: "82", height: "82" }))), h("div", { class: "content-wrapper" }, item['cta']['title'] && (h(Fragment, null, h("h3", null, item['cta']['title']), h("hr", null))), item['cta']['short_description'] && h("p", null, item['cta']['short_description']), item['cta']['button_type'] == 'v1' && item['cta']['button'] && (h("cradlepoint-button-cta", { link: formatHREF(this.domain, item['cta']['button']['url']) }, item['cta']['button']['title'])), item['cta']['button_type'] == 'v2' && item['cta']['buttons'] && (h("ul", null, item['cta']['buttons'].map((button) => {
                return (h("li", { class: "no-icon" }, h("a", { href: formatHREF(this.domain, button['button']['url']), target: "_self", class: "not-button" }, button['button']['title'])));
            }))))))));
        }))), h("div", { key: '7ba0af836ad11765e68c4de7e9f04746c94c88c4', class: "search-form-container" }, h("slot", { key: '1b010d2cab7968bdb666a525fad13fb8871a3d96', name: "search-form" })), h("div", { key: 'a4865b3eda45e13d1c8798e688ab08fcafdf504e', class: "nav-lang-container" }, h("slot", { key: '2a66c4dd50322cc86ff47e7af33d56c3cc96a1c3', name: "nav-lang" }))))));
    }
    get host() { return this; }
    static get style() { return CradlepointNavMainStyle0; }
}, [1, "cradlepoint-nav-main", {
        "domain": [1],
        "json": [1],
        "logo": [1],
        "logoLight": [1, "logo-light"],
        "logoDark": [1, "logo-dark"],
        "searchForm": [1, "search-form"],
        "navLang": [1, "nav-lang"],
        "showContact": [4, "show-contact"],
        "showSearch": [4, "show-search"],
        "showLanguageNav": [4, "show-language-nav"],
        "showSignIn": [4, "show-sign-in"],
        "altMobileLayout": [4, "alt-mobile-layout"],
        "countryCode": [1, "country-code"],
        "activeLang": [1, "active-lang"],
        "phoneNo": [1, "phone-no"],
        "homeLink": [1, "home-link"],
        "hoverTextColor": [1, "hover-text-color"]
    }, [[9, "resize", "handleResize"]]]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cradlepoint-nav-main", "cradlepoint-button-cta"];
    components.forEach(tagName => { switch (tagName) {
        case "cradlepoint-nav-main":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, NavMain);
            }
            break;
        case "cradlepoint-button-cta":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const CradlepointNavMain = NavMain;
const defineCustomElement = defineCustomElement$1;

export { CradlepointNavMain, defineCustomElement };

//# sourceMappingURL=cradlepoint-nav-main.js.map